// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: object_detection/protos/box_predictor.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3021000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3021005 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "object_detection/protos/hyperparams.pb.h"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct TableStruct_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto {
  static const uint32_t offsets[];
};
extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto;
namespace object_detection {
namespace protos {
class BoxPredictor;
struct BoxPredictorDefaultTypeInternal;
extern BoxPredictorDefaultTypeInternal _BoxPredictor_default_instance_;
class ConvolutionalBoxPredictor;
struct ConvolutionalBoxPredictorDefaultTypeInternal;
extern ConvolutionalBoxPredictorDefaultTypeInternal _ConvolutionalBoxPredictor_default_instance_;
class ConvolutionalBoxPredictor_BoxEncodingsClipRange;
struct ConvolutionalBoxPredictor_BoxEncodingsClipRangeDefaultTypeInternal;
extern ConvolutionalBoxPredictor_BoxEncodingsClipRangeDefaultTypeInternal _ConvolutionalBoxPredictor_BoxEncodingsClipRange_default_instance_;
class MaskRCNNBoxPredictor;
struct MaskRCNNBoxPredictorDefaultTypeInternal;
extern MaskRCNNBoxPredictorDefaultTypeInternal _MaskRCNNBoxPredictor_default_instance_;
class RfcnBoxPredictor;
struct RfcnBoxPredictorDefaultTypeInternal;
extern RfcnBoxPredictorDefaultTypeInternal _RfcnBoxPredictor_default_instance_;
class WeightSharedConvolutionalBoxPredictor;
struct WeightSharedConvolutionalBoxPredictorDefaultTypeInternal;
extern WeightSharedConvolutionalBoxPredictorDefaultTypeInternal _WeightSharedConvolutionalBoxPredictor_default_instance_;
class WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange;
struct WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRangeDefaultTypeInternal;
extern WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRangeDefaultTypeInternal _WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange_default_instance_;
}  // namespace protos
}  // namespace object_detection
PROTOBUF_NAMESPACE_OPEN
template<> ::object_detection::protos::BoxPredictor* Arena::CreateMaybeMessage<::object_detection::protos::BoxPredictor>(Arena*);
template<> ::object_detection::protos::ConvolutionalBoxPredictor* Arena::CreateMaybeMessage<::object_detection::protos::ConvolutionalBoxPredictor>(Arena*);
template<> ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* Arena::CreateMaybeMessage<::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange>(Arena*);
template<> ::object_detection::protos::MaskRCNNBoxPredictor* Arena::CreateMaybeMessage<::object_detection::protos::MaskRCNNBoxPredictor>(Arena*);
template<> ::object_detection::protos::RfcnBoxPredictor* Arena::CreateMaybeMessage<::object_detection::protos::RfcnBoxPredictor>(Arena*);
template<> ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* Arena::CreateMaybeMessage<::object_detection::protos::WeightSharedConvolutionalBoxPredictor>(Arena*);
template<> ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* Arena::CreateMaybeMessage<::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace object_detection {
namespace protos {

enum WeightSharedConvolutionalBoxPredictor_ScoreConverter : int {
  WeightSharedConvolutionalBoxPredictor_ScoreConverter_IDENTITY = 0,
  WeightSharedConvolutionalBoxPredictor_ScoreConverter_SIGMOID = 1
};
bool WeightSharedConvolutionalBoxPredictor_ScoreConverter_IsValid(int value);
constexpr WeightSharedConvolutionalBoxPredictor_ScoreConverter WeightSharedConvolutionalBoxPredictor_ScoreConverter_ScoreConverter_MIN = WeightSharedConvolutionalBoxPredictor_ScoreConverter_IDENTITY;
constexpr WeightSharedConvolutionalBoxPredictor_ScoreConverter WeightSharedConvolutionalBoxPredictor_ScoreConverter_ScoreConverter_MAX = WeightSharedConvolutionalBoxPredictor_ScoreConverter_SIGMOID;
constexpr int WeightSharedConvolutionalBoxPredictor_ScoreConverter_ScoreConverter_ARRAYSIZE = WeightSharedConvolutionalBoxPredictor_ScoreConverter_ScoreConverter_MAX + 1;

const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* WeightSharedConvolutionalBoxPredictor_ScoreConverter_descriptor();
template<typename T>
inline const std::string& WeightSharedConvolutionalBoxPredictor_ScoreConverter_Name(T enum_t_value) {
  static_assert(::std::is_same<T, WeightSharedConvolutionalBoxPredictor_ScoreConverter>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function WeightSharedConvolutionalBoxPredictor_ScoreConverter_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    WeightSharedConvolutionalBoxPredictor_ScoreConverter_descriptor(), enum_t_value);
}
inline bool WeightSharedConvolutionalBoxPredictor_ScoreConverter_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, WeightSharedConvolutionalBoxPredictor_ScoreConverter* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<WeightSharedConvolutionalBoxPredictor_ScoreConverter>(
    WeightSharedConvolutionalBoxPredictor_ScoreConverter_descriptor(), name, value);
}
// ===================================================================

class BoxPredictor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:object_detection.protos.BoxPredictor) */ {
 public:
  inline BoxPredictor() : BoxPredictor(nullptr) {}
  ~BoxPredictor() override;
  explicit PROTOBUF_CONSTEXPR BoxPredictor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  BoxPredictor(const BoxPredictor& from);
  BoxPredictor(BoxPredictor&& from) noexcept
    : BoxPredictor() {
    *this = ::std::move(from);
  }

  inline BoxPredictor& operator=(const BoxPredictor& from) {
    CopyFrom(from);
    return *this;
  }
  inline BoxPredictor& operator=(BoxPredictor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const BoxPredictor& default_instance() {
    return *internal_default_instance();
  }
  enum BoxPredictorOneofCase {
    kConvolutionalBoxPredictor = 1,
    kMaskRcnnBoxPredictor = 2,
    kRfcnBoxPredictor = 3,
    kWeightSharedConvolutionalBoxPredictor = 4,
    BOX_PREDICTOR_ONEOF_NOT_SET = 0,
  };

  static inline const BoxPredictor* internal_default_instance() {
    return reinterpret_cast<const BoxPredictor*>(
               &_BoxPredictor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(BoxPredictor& a, BoxPredictor& b) {
    a.Swap(&b);
  }
  inline void Swap(BoxPredictor* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(BoxPredictor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  BoxPredictor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<BoxPredictor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const BoxPredictor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom( const BoxPredictor& from) {
    BoxPredictor::MergeImpl(*this, from);
  }
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::PROTOBUF_NAMESPACE_ID::Arena* arena, bool is_message_owned);
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(BoxPredictor* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "object_detection.protos.BoxPredictor";
  }
  protected:
  explicit BoxPredictor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kConvolutionalBoxPredictorFieldNumber = 1,
    kMaskRcnnBoxPredictorFieldNumber = 2,
    kRfcnBoxPredictorFieldNumber = 3,
    kWeightSharedConvolutionalBoxPredictorFieldNumber = 4,
  };
  // .object_detection.protos.ConvolutionalBoxPredictor convolutional_box_predictor = 1;
  bool has_convolutional_box_predictor() const;
  private:
  bool _internal_has_convolutional_box_predictor() const;
  public:
  void clear_convolutional_box_predictor();
  const ::object_detection::protos::ConvolutionalBoxPredictor& convolutional_box_predictor() const;
  PROTOBUF_NODISCARD ::object_detection::protos::ConvolutionalBoxPredictor* release_convolutional_box_predictor();
  ::object_detection::protos::ConvolutionalBoxPredictor* mutable_convolutional_box_predictor();
  void set_allocated_convolutional_box_predictor(::object_detection::protos::ConvolutionalBoxPredictor* convolutional_box_predictor);
  private:
  const ::object_detection::protos::ConvolutionalBoxPredictor& _internal_convolutional_box_predictor() const;
  ::object_detection::protos::ConvolutionalBoxPredictor* _internal_mutable_convolutional_box_predictor();
  public:
  void unsafe_arena_set_allocated_convolutional_box_predictor(
      ::object_detection::protos::ConvolutionalBoxPredictor* convolutional_box_predictor);
  ::object_detection::protos::ConvolutionalBoxPredictor* unsafe_arena_release_convolutional_box_predictor();

  // .object_detection.protos.MaskRCNNBoxPredictor mask_rcnn_box_predictor = 2;
  bool has_mask_rcnn_box_predictor() const;
  private:
  bool _internal_has_mask_rcnn_box_predictor() const;
  public:
  void clear_mask_rcnn_box_predictor();
  const ::object_detection::protos::MaskRCNNBoxPredictor& mask_rcnn_box_predictor() const;
  PROTOBUF_NODISCARD ::object_detection::protos::MaskRCNNBoxPredictor* release_mask_rcnn_box_predictor();
  ::object_detection::protos::MaskRCNNBoxPredictor* mutable_mask_rcnn_box_predictor();
  void set_allocated_mask_rcnn_box_predictor(::object_detection::protos::MaskRCNNBoxPredictor* mask_rcnn_box_predictor);
  private:
  const ::object_detection::protos::MaskRCNNBoxPredictor& _internal_mask_rcnn_box_predictor() const;
  ::object_detection::protos::MaskRCNNBoxPredictor* _internal_mutable_mask_rcnn_box_predictor();
  public:
  void unsafe_arena_set_allocated_mask_rcnn_box_predictor(
      ::object_detection::protos::MaskRCNNBoxPredictor* mask_rcnn_box_predictor);
  ::object_detection::protos::MaskRCNNBoxPredictor* unsafe_arena_release_mask_rcnn_box_predictor();

  // .object_detection.protos.RfcnBoxPredictor rfcn_box_predictor = 3;
  bool has_rfcn_box_predictor() const;
  private:
  bool _internal_has_rfcn_box_predictor() const;
  public:
  void clear_rfcn_box_predictor();
  const ::object_detection::protos::RfcnBoxPredictor& rfcn_box_predictor() const;
  PROTOBUF_NODISCARD ::object_detection::protos::RfcnBoxPredictor* release_rfcn_box_predictor();
  ::object_detection::protos::RfcnBoxPredictor* mutable_rfcn_box_predictor();
  void set_allocated_rfcn_box_predictor(::object_detection::protos::RfcnBoxPredictor* rfcn_box_predictor);
  private:
  const ::object_detection::protos::RfcnBoxPredictor& _internal_rfcn_box_predictor() const;
  ::object_detection::protos::RfcnBoxPredictor* _internal_mutable_rfcn_box_predictor();
  public:
  void unsafe_arena_set_allocated_rfcn_box_predictor(
      ::object_detection::protos::RfcnBoxPredictor* rfcn_box_predictor);
  ::object_detection::protos::RfcnBoxPredictor* unsafe_arena_release_rfcn_box_predictor();

  // .object_detection.protos.WeightSharedConvolutionalBoxPredictor weight_shared_convolutional_box_predictor = 4;
  bool has_weight_shared_convolutional_box_predictor() const;
  private:
  bool _internal_has_weight_shared_convolutional_box_predictor() const;
  public:
  void clear_weight_shared_convolutional_box_predictor();
  const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor& weight_shared_convolutional_box_predictor() const;
  PROTOBUF_NODISCARD ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* release_weight_shared_convolutional_box_predictor();
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* mutable_weight_shared_convolutional_box_predictor();
  void set_allocated_weight_shared_convolutional_box_predictor(::object_detection::protos::WeightSharedConvolutionalBoxPredictor* weight_shared_convolutional_box_predictor);
  private:
  const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor& _internal_weight_shared_convolutional_box_predictor() const;
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* _internal_mutable_weight_shared_convolutional_box_predictor();
  public:
  void unsafe_arena_set_allocated_weight_shared_convolutional_box_predictor(
      ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* weight_shared_convolutional_box_predictor);
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* unsafe_arena_release_weight_shared_convolutional_box_predictor();

  void clear_box_predictor_oneof();
  BoxPredictorOneofCase box_predictor_oneof_case() const;
  // @@protoc_insertion_point(class_scope:object_detection.protos.BoxPredictor)
 private:
  class _Internal;
  void set_has_convolutional_box_predictor();
  void set_has_mask_rcnn_box_predictor();
  void set_has_rfcn_box_predictor();
  void set_has_weight_shared_convolutional_box_predictor();

  inline bool has_box_predictor_oneof() const;
  inline void clear_has_box_predictor_oneof();

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  struct Impl_ {
    union BoxPredictorOneofUnion {
      constexpr BoxPredictorOneofUnion() : _constinit_{} {}
        ::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized _constinit_;
      ::object_detection::protos::ConvolutionalBoxPredictor* convolutional_box_predictor_;
      ::object_detection::protos::MaskRCNNBoxPredictor* mask_rcnn_box_predictor_;
      ::object_detection::protos::RfcnBoxPredictor* rfcn_box_predictor_;
      ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* weight_shared_convolutional_box_predictor_;
    } box_predictor_oneof_;
    mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
    uint32_t _oneof_case_[1];

  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto;
};
// -------------------------------------------------------------------

class ConvolutionalBoxPredictor_BoxEncodingsClipRange final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange) */ {
 public:
  inline ConvolutionalBoxPredictor_BoxEncodingsClipRange() : ConvolutionalBoxPredictor_BoxEncodingsClipRange(nullptr) {}
  ~ConvolutionalBoxPredictor_BoxEncodingsClipRange() override;
  explicit PROTOBUF_CONSTEXPR ConvolutionalBoxPredictor_BoxEncodingsClipRange(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  ConvolutionalBoxPredictor_BoxEncodingsClipRange(const ConvolutionalBoxPredictor_BoxEncodingsClipRange& from);
  ConvolutionalBoxPredictor_BoxEncodingsClipRange(ConvolutionalBoxPredictor_BoxEncodingsClipRange&& from) noexcept
    : ConvolutionalBoxPredictor_BoxEncodingsClipRange() {
    *this = ::std::move(from);
  }

  inline ConvolutionalBoxPredictor_BoxEncodingsClipRange& operator=(const ConvolutionalBoxPredictor_BoxEncodingsClipRange& from) {
    CopyFrom(from);
    return *this;
  }
  inline ConvolutionalBoxPredictor_BoxEncodingsClipRange& operator=(ConvolutionalBoxPredictor_BoxEncodingsClipRange&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const ConvolutionalBoxPredictor_BoxEncodingsClipRange& default_instance() {
    return *internal_default_instance();
  }
  static inline const ConvolutionalBoxPredictor_BoxEncodingsClipRange* internal_default_instance() {
    return reinterpret_cast<const ConvolutionalBoxPredictor_BoxEncodingsClipRange*>(
               &_ConvolutionalBoxPredictor_BoxEncodingsClipRange_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(ConvolutionalBoxPredictor_BoxEncodingsClipRange& a, ConvolutionalBoxPredictor_BoxEncodingsClipRange& b) {
    a.Swap(&b);
  }
  inline void Swap(ConvolutionalBoxPredictor_BoxEncodingsClipRange* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ConvolutionalBoxPredictor_BoxEncodingsClipRange* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  ConvolutionalBoxPredictor_BoxEncodingsClipRange* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<ConvolutionalBoxPredictor_BoxEncodingsClipRange>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const ConvolutionalBoxPredictor_BoxEncodingsClipRange& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom( const ConvolutionalBoxPredictor_BoxEncodingsClipRange& from) {
    ConvolutionalBoxPredictor_BoxEncodingsClipRange::MergeImpl(*this, from);
  }
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::PROTOBUF_NAMESPACE_ID::Arena* arena, bool is_message_owned);
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(ConvolutionalBoxPredictor_BoxEncodingsClipRange* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange";
  }
  protected:
  explicit ConvolutionalBoxPredictor_BoxEncodingsClipRange(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kMinFieldNumber = 1,
    kMaxFieldNumber = 2,
  };
  // optional float min = 1;
  bool has_min() const;
  private:
  bool _internal_has_min() const;
  public:
  void clear_min();
  float min() const;
  void set_min(float value);
  private:
  float _internal_min() const;
  void _internal_set_min(float value);
  public:

  // optional float max = 2;
  bool has_max() const;
  private:
  bool _internal_has_max() const;
  public:
  void clear_max();
  float max() const;
  void set_max(float value);
  private:
  float _internal_max() const;
  void _internal_set_max(float value);
  public:

  // @@protoc_insertion_point(class_scope:object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  struct Impl_ {
    ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
    mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
    float min_;
    float max_;
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto;
};
// -------------------------------------------------------------------

class ConvolutionalBoxPredictor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:object_detection.protos.ConvolutionalBoxPredictor) */ {
 public:
  inline ConvolutionalBoxPredictor() : ConvolutionalBoxPredictor(nullptr) {}
  ~ConvolutionalBoxPredictor() override;
  explicit PROTOBUF_CONSTEXPR ConvolutionalBoxPredictor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  ConvolutionalBoxPredictor(const ConvolutionalBoxPredictor& from);
  ConvolutionalBoxPredictor(ConvolutionalBoxPredictor&& from) noexcept
    : ConvolutionalBoxPredictor() {
    *this = ::std::move(from);
  }

  inline ConvolutionalBoxPredictor& operator=(const ConvolutionalBoxPredictor& from) {
    CopyFrom(from);
    return *this;
  }
  inline ConvolutionalBoxPredictor& operator=(ConvolutionalBoxPredictor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const ConvolutionalBoxPredictor& default_instance() {
    return *internal_default_instance();
  }
  static inline const ConvolutionalBoxPredictor* internal_default_instance() {
    return reinterpret_cast<const ConvolutionalBoxPredictor*>(
               &_ConvolutionalBoxPredictor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    2;

  friend void swap(ConvolutionalBoxPredictor& a, ConvolutionalBoxPredictor& b) {
    a.Swap(&b);
  }
  inline void Swap(ConvolutionalBoxPredictor* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ConvolutionalBoxPredictor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  ConvolutionalBoxPredictor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<ConvolutionalBoxPredictor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const ConvolutionalBoxPredictor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom( const ConvolutionalBoxPredictor& from) {
    ConvolutionalBoxPredictor::MergeImpl(*this, from);
  }
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::PROTOBUF_NAMESPACE_ID::Arena* arena, bool is_message_owned);
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(ConvolutionalBoxPredictor* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "object_detection.protos.ConvolutionalBoxPredictor";
  }
  protected:
  explicit ConvolutionalBoxPredictor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef ConvolutionalBoxPredictor_BoxEncodingsClipRange BoxEncodingsClipRange;

  // accessors -------------------------------------------------------

  enum : int {
    kConvHyperparamsFieldNumber = 1,
    kBoxEncodingsClipRangeFieldNumber = 12,
    kMinDepthFieldNumber = 2,
    kMaxDepthFieldNumber = 3,
    kNumLayersBeforePredictorFieldNumber = 4,
    kClassPredictionBiasInitFieldNumber = 10,
    kApplySigmoidToScoresFieldNumber = 9,
    kUseDepthwiseFieldNumber = 11,
    kUseDropoutFieldNumber = 5,
    kDropoutKeepProbabilityFieldNumber = 6,
    kKernelSizeFieldNumber = 7,
    kBoxCodeSizeFieldNumber = 8,
  };
  // optional .object_detection.protos.Hyperparams conv_hyperparams = 1;
  bool has_conv_hyperparams() const;
  private:
  bool _internal_has_conv_hyperparams() const;
  public:
  void clear_conv_hyperparams();
  const ::object_detection::protos::Hyperparams& conv_hyperparams() const;
  PROTOBUF_NODISCARD ::object_detection::protos::Hyperparams* release_conv_hyperparams();
  ::object_detection::protos::Hyperparams* mutable_conv_hyperparams();
  void set_allocated_conv_hyperparams(::object_detection::protos::Hyperparams* conv_hyperparams);
  private:
  const ::object_detection::protos::Hyperparams& _internal_conv_hyperparams() const;
  ::object_detection::protos::Hyperparams* _internal_mutable_conv_hyperparams();
  public:
  void unsafe_arena_set_allocated_conv_hyperparams(
      ::object_detection::protos::Hyperparams* conv_hyperparams);
  ::object_detection::protos::Hyperparams* unsafe_arena_release_conv_hyperparams();

  // optional .object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange box_encodings_clip_range = 12;
  bool has_box_encodings_clip_range() const;
  private:
  bool _internal_has_box_encodings_clip_range() const;
  public:
  void clear_box_encodings_clip_range();
  const ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange& box_encodings_clip_range() const;
  PROTOBUF_NODISCARD ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* release_box_encodings_clip_range();
  ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* mutable_box_encodings_clip_range();
  void set_allocated_box_encodings_clip_range(::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range);
  private:
  const ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange& _internal_box_encodings_clip_range() const;
  ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* _internal_mutable_box_encodings_clip_range();
  public:
  void unsafe_arena_set_allocated_box_encodings_clip_range(
      ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range);
  ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* unsafe_arena_release_box_encodings_clip_range();

  // optional int32 min_depth = 2 [default = 0];
  bool has_min_depth() const;
  private:
  bool _internal_has_min_depth() const;
  public:
  void clear_min_depth();
  int32_t min_depth() const;
  void set_min_depth(int32_t value);
  private:
  int32_t _internal_min_depth() const;
  void _internal_set_min_depth(int32_t value);
  public:

  // optional int32 max_depth = 3 [default = 0];
  bool has_max_depth() const;
  private:
  bool _internal_has_max_depth() const;
  public:
  void clear_max_depth();
  int32_t max_depth() const;
  void set_max_depth(int32_t value);
  private:
  int32_t _internal_max_depth() const;
  void _internal_set_max_depth(int32_t value);
  public:

  // optional int32 num_layers_before_predictor = 4 [default = 0];
  bool has_num_layers_before_predictor() const;
  private:
  bool _internal_has_num_layers_before_predictor() const;
  public:
  void clear_num_layers_before_predictor();
  int32_t num_layers_before_predictor() const;
  void set_num_layers_before_predictor(int32_t value);
  private:
  int32_t _internal_num_layers_before_predictor() const;
  void _internal_set_num_layers_before_predictor(int32_t value);
  public:

  // optional float class_prediction_bias_init = 10 [default = 0];
  bool has_class_prediction_bias_init() const;
  private:
  bool _internal_has_class_prediction_bias_init() const;
  public:
  void clear_class_prediction_bias_init();
  float class_prediction_bias_init() const;
  void set_class_prediction_bias_init(float value);
  private:
  float _internal_class_prediction_bias_init() const;
  void _internal_set_class_prediction_bias_init(float value);
  public:

  // optional bool apply_sigmoid_to_scores = 9 [default = false];
  bool has_apply_sigmoid_to_scores() const;
  private:
  bool _internal_has_apply_sigmoid_to_scores() const;
  public:
  void clear_apply_sigmoid_to_scores();
  bool apply_sigmoid_to_scores() const;
  void set_apply_sigmoid_to_scores(bool value);
  private:
  bool _internal_apply_sigmoid_to_scores() const;
  void _internal_set_apply_sigmoid_to_scores(bool value);
  public:

  // optional bool use_depthwise = 11 [default = false];
  bool has_use_depthwise() const;
  private:
  bool _internal_has_use_depthwise() const;
  public:
  void clear_use_depthwise();
  bool use_depthwise() const;
  void set_use_depthwise(bool value);
  private:
  bool _internal_use_depthwise() const;
  void _internal_set_use_depthwise(bool value);
  public:

  // optional bool use_dropout = 5 [default = true];
  bool has_use_dropout() const;
  private:
  bool _internal_has_use_dropout() const;
  public:
  void clear_use_dropout();
  bool use_dropout() const;
  void set_use_dropout(bool value);
  private:
  bool _internal_use_dropout() const;
  void _internal_set_use_dropout(bool value);
  public:

  // optional float dropout_keep_probability = 6 [default = 0.8];
  bool has_dropout_keep_probability() const;
  private:
  bool _internal_has_dropout_keep_probability() const;
  public:
  void clear_dropout_keep_probability();
  float dropout_keep_probability() const;
  void set_dropout_keep_probability(float value);
  private:
  float _internal_dropout_keep_probability() const;
  void _internal_set_dropout_keep_probability(float value);
  public:

  // optional int32 kernel_size = 7 [default = 1];
  bool has_kernel_size() const;
  private:
  bool _internal_has_kernel_size() const;
  public:
  void clear_kernel_size();
  int32_t kernel_size() const;
  void set_kernel_size(int32_t value);
  private:
  int32_t _internal_kernel_size() const;
  void _internal_set_kernel_size(int32_t value);
  public:

  // optional int32 box_code_size = 8 [default = 4];
  bool has_box_code_size() const;
  private:
  bool _internal_has_box_code_size() const;
  public:
  void clear_box_code_size();
  int32_t box_code_size() const;
  void set_box_code_size(int32_t value);
  private:
  int32_t _internal_box_code_size() const;
  void _internal_set_box_code_size(int32_t value);
  public:

  // @@protoc_insertion_point(class_scope:object_detection.protos.ConvolutionalBoxPredictor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  struct Impl_ {
    ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
    mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
    ::object_detection::protos::Hyperparams* conv_hyperparams_;
    ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range_;
    int32_t min_depth_;
    int32_t max_depth_;
    int32_t num_layers_before_predictor_;
    float class_prediction_bias_init_;
    bool apply_sigmoid_to_scores_;
    bool use_depthwise_;
    bool use_dropout_;
    float dropout_keep_probability_;
    int32_t kernel_size_;
    int32_t box_code_size_;
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto;
};
// -------------------------------------------------------------------

class WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange) */ {
 public:
  inline WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange() : WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange(nullptr) {}
  ~WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange() override;
  explicit PROTOBUF_CONSTEXPR WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange(const WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& from);
  WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange(WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange&& from) noexcept
    : WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange() {
    *this = ::std::move(from);
  }

  inline WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& operator=(const WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& from) {
    CopyFrom(from);
    return *this;
  }
  inline WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& operator=(WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& default_instance() {
    return *internal_default_instance();
  }
  static inline const WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* internal_default_instance() {
    return reinterpret_cast<const WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange*>(
               &_WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    3;

  friend void swap(WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& a, WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& b) {
    a.Swap(&b);
  }
  inline void Swap(WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom( const WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& from) {
    WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::MergeImpl(*this, from);
  }
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::PROTOBUF_NAMESPACE_ID::Arena* arena, bool is_message_owned);
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange";
  }
  protected:
  explicit WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kMinFieldNumber = 1,
    kMaxFieldNumber = 2,
  };
  // optional float min = 1;
  bool has_min() const;
  private:
  bool _internal_has_min() const;
  public:
  void clear_min();
  float min() const;
  void set_min(float value);
  private:
  float _internal_min() const;
  void _internal_set_min(float value);
  public:

  // optional float max = 2;
  bool has_max() const;
  private:
  bool _internal_has_max() const;
  public:
  void clear_max();
  float max() const;
  void set_max(float value);
  private:
  float _internal_max() const;
  void _internal_set_max(float value);
  public:

  // @@protoc_insertion_point(class_scope:object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  struct Impl_ {
    ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
    mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
    float min_;
    float max_;
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto;
};
// -------------------------------------------------------------------

class WeightSharedConvolutionalBoxPredictor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:object_detection.protos.WeightSharedConvolutionalBoxPredictor) */ {
 public:
  inline WeightSharedConvolutionalBoxPredictor() : WeightSharedConvolutionalBoxPredictor(nullptr) {}
  ~WeightSharedConvolutionalBoxPredictor() override;
  explicit PROTOBUF_CONSTEXPR WeightSharedConvolutionalBoxPredictor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  WeightSharedConvolutionalBoxPredictor(const WeightSharedConvolutionalBoxPredictor& from);
  WeightSharedConvolutionalBoxPredictor(WeightSharedConvolutionalBoxPredictor&& from) noexcept
    : WeightSharedConvolutionalBoxPredictor() {
    *this = ::std::move(from);
  }

  inline WeightSharedConvolutionalBoxPredictor& operator=(const WeightSharedConvolutionalBoxPredictor& from) {
    CopyFrom(from);
    return *this;
  }
  inline WeightSharedConvolutionalBoxPredictor& operator=(WeightSharedConvolutionalBoxPredictor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const WeightSharedConvolutionalBoxPredictor& default_instance() {
    return *internal_default_instance();
  }
  static inline const WeightSharedConvolutionalBoxPredictor* internal_default_instance() {
    return reinterpret_cast<const WeightSharedConvolutionalBoxPredictor*>(
               &_WeightSharedConvolutionalBoxPredictor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    4;

  friend void swap(WeightSharedConvolutionalBoxPredictor& a, WeightSharedConvolutionalBoxPredictor& b) {
    a.Swap(&b);
  }
  inline void Swap(WeightSharedConvolutionalBoxPredictor* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(WeightSharedConvolutionalBoxPredictor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  WeightSharedConvolutionalBoxPredictor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<WeightSharedConvolutionalBoxPredictor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const WeightSharedConvolutionalBoxPredictor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom( const WeightSharedConvolutionalBoxPredictor& from) {
    WeightSharedConvolutionalBoxPredictor::MergeImpl(*this, from);
  }
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::PROTOBUF_NAMESPACE_ID::Arena* arena, bool is_message_owned);
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(WeightSharedConvolutionalBoxPredictor* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "object_detection.protos.WeightSharedConvolutionalBoxPredictor";
  }
  protected:
  explicit WeightSharedConvolutionalBoxPredictor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange BoxEncodingsClipRange;

  typedef WeightSharedConvolutionalBoxPredictor_ScoreConverter ScoreConverter;
  static constexpr ScoreConverter IDENTITY =
    WeightSharedConvolutionalBoxPredictor_ScoreConverter_IDENTITY;
  static constexpr ScoreConverter SIGMOID =
    WeightSharedConvolutionalBoxPredictor_ScoreConverter_SIGMOID;
  static inline bool ScoreConverter_IsValid(int value) {
    return WeightSharedConvolutionalBoxPredictor_ScoreConverter_IsValid(value);
  }
  static constexpr ScoreConverter ScoreConverter_MIN =
    WeightSharedConvolutionalBoxPredictor_ScoreConverter_ScoreConverter_MIN;
  static constexpr ScoreConverter ScoreConverter_MAX =
    WeightSharedConvolutionalBoxPredictor_ScoreConverter_ScoreConverter_MAX;
  static constexpr int ScoreConverter_ARRAYSIZE =
    WeightSharedConvolutionalBoxPredictor_ScoreConverter_ScoreConverter_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  ScoreConverter_descriptor() {
    return WeightSharedConvolutionalBoxPredictor_ScoreConverter_descriptor();
  }
  template<typename T>
  static inline const std::string& ScoreConverter_Name(T enum_t_value) {
    static_assert(::std::is_same<T, ScoreConverter>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function ScoreConverter_Name.");
    return WeightSharedConvolutionalBoxPredictor_ScoreConverter_Name(enum_t_value);
  }
  static inline bool ScoreConverter_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      ScoreConverter* value) {
    return WeightSharedConvolutionalBoxPredictor_ScoreConverter_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kConvHyperparamsFieldNumber = 1,
    kBoxEncodingsClipRangeFieldNumber = 17,
    kDepthFieldNumber = 2,
    kNumLayersBeforePredictorFieldNumber = 4,
    kClassPredictionBiasInitFieldNumber = 10,
    kUseDropoutFieldNumber = 11,
    kSharePredictionTowerFieldNumber = 13,
    kUseDepthwiseFieldNumber = 14,
    kScoreConverterFieldNumber = 16,
    kDropoutKeepProbabilityFieldNumber = 12,
    kKernelSizeFieldNumber = 7,
    kBoxCodeSizeFieldNumber = 8,
  };
  // optional .object_detection.protos.Hyperparams conv_hyperparams = 1;
  bool has_conv_hyperparams() const;
  private:
  bool _internal_has_conv_hyperparams() const;
  public:
  void clear_conv_hyperparams();
  const ::object_detection::protos::Hyperparams& conv_hyperparams() const;
  PROTOBUF_NODISCARD ::object_detection::protos::Hyperparams* release_conv_hyperparams();
  ::object_detection::protos::Hyperparams* mutable_conv_hyperparams();
  void set_allocated_conv_hyperparams(::object_detection::protos::Hyperparams* conv_hyperparams);
  private:
  const ::object_detection::protos::Hyperparams& _internal_conv_hyperparams() const;
  ::object_detection::protos::Hyperparams* _internal_mutable_conv_hyperparams();
  public:
  void unsafe_arena_set_allocated_conv_hyperparams(
      ::object_detection::protos::Hyperparams* conv_hyperparams);
  ::object_detection::protos::Hyperparams* unsafe_arena_release_conv_hyperparams();

  // optional .object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange box_encodings_clip_range = 17;
  bool has_box_encodings_clip_range() const;
  private:
  bool _internal_has_box_encodings_clip_range() const;
  public:
  void clear_box_encodings_clip_range();
  const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& box_encodings_clip_range() const;
  PROTOBUF_NODISCARD ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* release_box_encodings_clip_range();
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* mutable_box_encodings_clip_range();
  void set_allocated_box_encodings_clip_range(::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range);
  private:
  const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& _internal_box_encodings_clip_range() const;
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* _internal_mutable_box_encodings_clip_range();
  public:
  void unsafe_arena_set_allocated_box_encodings_clip_range(
      ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range);
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* unsafe_arena_release_box_encodings_clip_range();

  // optional int32 depth = 2 [default = 0];
  bool has_depth() const;
  private:
  bool _internal_has_depth() const;
  public:
  void clear_depth();
  int32_t depth() const;
  void set_depth(int32_t value);
  private:
  int32_t _internal_depth() const;
  void _internal_set_depth(int32_t value);
  public:

  // optional int32 num_layers_before_predictor = 4 [default = 0];
  bool has_num_layers_before_predictor() const;
  private:
  bool _internal_has_num_layers_before_predictor() const;
  public:
  void clear_num_layers_before_predictor();
  int32_t num_layers_before_predictor() const;
  void set_num_layers_before_predictor(int32_t value);
  private:
  int32_t _internal_num_layers_before_predictor() const;
  void _internal_set_num_layers_before_predictor(int32_t value);
  public:

  // optional float class_prediction_bias_init = 10 [default = 0];
  bool has_class_prediction_bias_init() const;
  private:
  bool _internal_has_class_prediction_bias_init() const;
  public:
  void clear_class_prediction_bias_init();
  float class_prediction_bias_init() const;
  void set_class_prediction_bias_init(float value);
  private:
  float _internal_class_prediction_bias_init() const;
  void _internal_set_class_prediction_bias_init(float value);
  public:

  // optional bool use_dropout = 11 [default = false];
  bool has_use_dropout() const;
  private:
  bool _internal_has_use_dropout() const;
  public:
  void clear_use_dropout();
  bool use_dropout() const;
  void set_use_dropout(bool value);
  private:
  bool _internal_use_dropout() const;
  void _internal_set_use_dropout(bool value);
  public:

  // optional bool share_prediction_tower = 13 [default = false];
  bool has_share_prediction_tower() const;
  private:
  bool _internal_has_share_prediction_tower() const;
  public:
  void clear_share_prediction_tower();
  bool share_prediction_tower() const;
  void set_share_prediction_tower(bool value);
  private:
  bool _internal_share_prediction_tower() const;
  void _internal_set_share_prediction_tower(bool value);
  public:

  // optional bool use_depthwise = 14 [default = false];
  bool has_use_depthwise() const;
  private:
  bool _internal_has_use_depthwise() const;
  public:
  void clear_use_depthwise();
  bool use_depthwise() const;
  void set_use_depthwise(bool value);
  private:
  bool _internal_use_depthwise() const;
  void _internal_set_use_depthwise(bool value);
  public:

  // optional .object_detection.protos.WeightSharedConvolutionalBoxPredictor.ScoreConverter score_converter = 16 [default = IDENTITY];
  bool has_score_converter() const;
  private:
  bool _internal_has_score_converter() const;
  public:
  void clear_score_converter();
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter score_converter() const;
  void set_score_converter(::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter value);
  private:
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter _internal_score_converter() const;
  void _internal_set_score_converter(::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter value);
  public:

  // optional float dropout_keep_probability = 12 [default = 0.8];
  bool has_dropout_keep_probability() const;
  private:
  bool _internal_has_dropout_keep_probability() const;
  public:
  void clear_dropout_keep_probability();
  float dropout_keep_probability() const;
  void set_dropout_keep_probability(float value);
  private:
  float _internal_dropout_keep_probability() const;
  void _internal_set_dropout_keep_probability(float value);
  public:

  // optional int32 kernel_size = 7 [default = 3];
  bool has_kernel_size() const;
  private:
  bool _internal_has_kernel_size() const;
  public:
  void clear_kernel_size();
  int32_t kernel_size() const;
  void set_kernel_size(int32_t value);
  private:
  int32_t _internal_kernel_size() const;
  void _internal_set_kernel_size(int32_t value);
  public:

  // optional int32 box_code_size = 8 [default = 4];
  bool has_box_code_size() const;
  private:
  bool _internal_has_box_code_size() const;
  public:
  void clear_box_code_size();
  int32_t box_code_size() const;
  void set_box_code_size(int32_t value);
  private:
  int32_t _internal_box_code_size() const;
  void _internal_set_box_code_size(int32_t value);
  public:

  // @@protoc_insertion_point(class_scope:object_detection.protos.WeightSharedConvolutionalBoxPredictor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  struct Impl_ {
    ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
    mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
    ::object_detection::protos::Hyperparams* conv_hyperparams_;
    ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range_;
    int32_t depth_;
    int32_t num_layers_before_predictor_;
    float class_prediction_bias_init_;
    bool use_dropout_;
    bool share_prediction_tower_;
    bool use_depthwise_;
    int score_converter_;
    float dropout_keep_probability_;
    int32_t kernel_size_;
    int32_t box_code_size_;
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto;
};
// -------------------------------------------------------------------

class MaskRCNNBoxPredictor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:object_detection.protos.MaskRCNNBoxPredictor) */ {
 public:
  inline MaskRCNNBoxPredictor() : MaskRCNNBoxPredictor(nullptr) {}
  ~MaskRCNNBoxPredictor() override;
  explicit PROTOBUF_CONSTEXPR MaskRCNNBoxPredictor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  MaskRCNNBoxPredictor(const MaskRCNNBoxPredictor& from);
  MaskRCNNBoxPredictor(MaskRCNNBoxPredictor&& from) noexcept
    : MaskRCNNBoxPredictor() {
    *this = ::std::move(from);
  }

  inline MaskRCNNBoxPredictor& operator=(const MaskRCNNBoxPredictor& from) {
    CopyFrom(from);
    return *this;
  }
  inline MaskRCNNBoxPredictor& operator=(MaskRCNNBoxPredictor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const MaskRCNNBoxPredictor& default_instance() {
    return *internal_default_instance();
  }
  static inline const MaskRCNNBoxPredictor* internal_default_instance() {
    return reinterpret_cast<const MaskRCNNBoxPredictor*>(
               &_MaskRCNNBoxPredictor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    5;

  friend void swap(MaskRCNNBoxPredictor& a, MaskRCNNBoxPredictor& b) {
    a.Swap(&b);
  }
  inline void Swap(MaskRCNNBoxPredictor* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(MaskRCNNBoxPredictor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  MaskRCNNBoxPredictor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<MaskRCNNBoxPredictor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const MaskRCNNBoxPredictor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom( const MaskRCNNBoxPredictor& from) {
    MaskRCNNBoxPredictor::MergeImpl(*this, from);
  }
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::PROTOBUF_NAMESPACE_ID::Arena* arena, bool is_message_owned);
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(MaskRCNNBoxPredictor* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "object_detection.protos.MaskRCNNBoxPredictor";
  }
  protected:
  explicit MaskRCNNBoxPredictor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kFcHyperparamsFieldNumber = 1,
    kConvHyperparamsFieldNumber = 5,
    kUseDropoutFieldNumber = 2,
    kPredictInstanceMasksFieldNumber = 6,
    kPredictKeypointsFieldNumber = 8,
    kMasksAreClassAgnosticFieldNumber = 12,
    kShareBoxAcrossClassesFieldNumber = 13,
    kConvolveThenUpsampleMasksFieldNumber = 14,
    kDropoutKeepProbabilityFieldNumber = 3,
    kBoxCodeSizeFieldNumber = 4,
    kMaskPredictionConvDepthFieldNumber = 7,
    kMaskHeightFieldNumber = 9,
    kMaskWidthFieldNumber = 10,
    kMaskPredictionNumConvLayersFieldNumber = 11,
  };
  // optional .object_detection.protos.Hyperparams fc_hyperparams = 1;
  bool has_fc_hyperparams() const;
  private:
  bool _internal_has_fc_hyperparams() const;
  public:
  void clear_fc_hyperparams();
  const ::object_detection::protos::Hyperparams& fc_hyperparams() const;
  PROTOBUF_NODISCARD ::object_detection::protos::Hyperparams* release_fc_hyperparams();
  ::object_detection::protos::Hyperparams* mutable_fc_hyperparams();
  void set_allocated_fc_hyperparams(::object_detection::protos::Hyperparams* fc_hyperparams);
  private:
  const ::object_detection::protos::Hyperparams& _internal_fc_hyperparams() const;
  ::object_detection::protos::Hyperparams* _internal_mutable_fc_hyperparams();
  public:
  void unsafe_arena_set_allocated_fc_hyperparams(
      ::object_detection::protos::Hyperparams* fc_hyperparams);
  ::object_detection::protos::Hyperparams* unsafe_arena_release_fc_hyperparams();

  // optional .object_detection.protos.Hyperparams conv_hyperparams = 5;
  bool has_conv_hyperparams() const;
  private:
  bool _internal_has_conv_hyperparams() const;
  public:
  void clear_conv_hyperparams();
  const ::object_detection::protos::Hyperparams& conv_hyperparams() const;
  PROTOBUF_NODISCARD ::object_detection::protos::Hyperparams* release_conv_hyperparams();
  ::object_detection::protos::Hyperparams* mutable_conv_hyperparams();
  void set_allocated_conv_hyperparams(::object_detection::protos::Hyperparams* conv_hyperparams);
  private:
  const ::object_detection::protos::Hyperparams& _internal_conv_hyperparams() const;
  ::object_detection::protos::Hyperparams* _internal_mutable_conv_hyperparams();
  public:
  void unsafe_arena_set_allocated_conv_hyperparams(
      ::object_detection::protos::Hyperparams* conv_hyperparams);
  ::object_detection::protos::Hyperparams* unsafe_arena_release_conv_hyperparams();

  // optional bool use_dropout = 2 [default = false];
  bool has_use_dropout() const;
  private:
  bool _internal_has_use_dropout() const;
  public:
  void clear_use_dropout();
  bool use_dropout() const;
  void set_use_dropout(bool value);
  private:
  bool _internal_use_dropout() const;
  void _internal_set_use_dropout(bool value);
  public:

  // optional bool predict_instance_masks = 6 [default = false];
  bool has_predict_instance_masks() const;
  private:
  bool _internal_has_predict_instance_masks() const;
  public:
  void clear_predict_instance_masks();
  bool predict_instance_masks() const;
  void set_predict_instance_masks(bool value);
  private:
  bool _internal_predict_instance_masks() const;
  void _internal_set_predict_instance_masks(bool value);
  public:

  // optional bool predict_keypoints = 8 [default = false];
  bool has_predict_keypoints() const;
  private:
  bool _internal_has_predict_keypoints() const;
  public:
  void clear_predict_keypoints();
  bool predict_keypoints() const;
  void set_predict_keypoints(bool value);
  private:
  bool _internal_predict_keypoints() const;
  void _internal_set_predict_keypoints(bool value);
  public:

  // optional bool masks_are_class_agnostic = 12 [default = false];
  bool has_masks_are_class_agnostic() const;
  private:
  bool _internal_has_masks_are_class_agnostic() const;
  public:
  void clear_masks_are_class_agnostic();
  bool masks_are_class_agnostic() const;
  void set_masks_are_class_agnostic(bool value);
  private:
  bool _internal_masks_are_class_agnostic() const;
  void _internal_set_masks_are_class_agnostic(bool value);
  public:

  // optional bool share_box_across_classes = 13 [default = false];
  bool has_share_box_across_classes() const;
  private:
  bool _internal_has_share_box_across_classes() const;
  public:
  void clear_share_box_across_classes();
  bool share_box_across_classes() const;
  void set_share_box_across_classes(bool value);
  private:
  bool _internal_share_box_across_classes() const;
  void _internal_set_share_box_across_classes(bool value);
  public:

  // optional bool convolve_then_upsample_masks = 14 [default = false];
  bool has_convolve_then_upsample_masks() const;
  private:
  bool _internal_has_convolve_then_upsample_masks() const;
  public:
  void clear_convolve_then_upsample_masks();
  bool convolve_then_upsample_masks() const;
  void set_convolve_then_upsample_masks(bool value);
  private:
  bool _internal_convolve_then_upsample_masks() const;
  void _internal_set_convolve_then_upsample_masks(bool value);
  public:

  // optional float dropout_keep_probability = 3 [default = 0.5];
  bool has_dropout_keep_probability() const;
  private:
  bool _internal_has_dropout_keep_probability() const;
  public:
  void clear_dropout_keep_probability();
  float dropout_keep_probability() const;
  void set_dropout_keep_probability(float value);
  private:
  float _internal_dropout_keep_probability() const;
  void _internal_set_dropout_keep_probability(float value);
  public:

  // optional int32 box_code_size = 4 [default = 4];
  bool has_box_code_size() const;
  private:
  bool _internal_has_box_code_size() const;
  public:
  void clear_box_code_size();
  int32_t box_code_size() const;
  void set_box_code_size(int32_t value);
  private:
  int32_t _internal_box_code_size() const;
  void _internal_set_box_code_size(int32_t value);
  public:

  // optional int32 mask_prediction_conv_depth = 7 [default = 256];
  bool has_mask_prediction_conv_depth() const;
  private:
  bool _internal_has_mask_prediction_conv_depth() const;
  public:
  void clear_mask_prediction_conv_depth();
  int32_t mask_prediction_conv_depth() const;
  void set_mask_prediction_conv_depth(int32_t value);
  private:
  int32_t _internal_mask_prediction_conv_depth() const;
  void _internal_set_mask_prediction_conv_depth(int32_t value);
  public:

  // optional int32 mask_height = 9 [default = 15];
  bool has_mask_height() const;
  private:
  bool _internal_has_mask_height() const;
  public:
  void clear_mask_height();
  int32_t mask_height() const;
  void set_mask_height(int32_t value);
  private:
  int32_t _internal_mask_height() const;
  void _internal_set_mask_height(int32_t value);
  public:

  // optional int32 mask_width = 10 [default = 15];
  bool has_mask_width() const;
  private:
  bool _internal_has_mask_width() const;
  public:
  void clear_mask_width();
  int32_t mask_width() const;
  void set_mask_width(int32_t value);
  private:
  int32_t _internal_mask_width() const;
  void _internal_set_mask_width(int32_t value);
  public:

  // optional int32 mask_prediction_num_conv_layers = 11 [default = 2];
  bool has_mask_prediction_num_conv_layers() const;
  private:
  bool _internal_has_mask_prediction_num_conv_layers() const;
  public:
  void clear_mask_prediction_num_conv_layers();
  int32_t mask_prediction_num_conv_layers() const;
  void set_mask_prediction_num_conv_layers(int32_t value);
  private:
  int32_t _internal_mask_prediction_num_conv_layers() const;
  void _internal_set_mask_prediction_num_conv_layers(int32_t value);
  public:

  // @@protoc_insertion_point(class_scope:object_detection.protos.MaskRCNNBoxPredictor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  struct Impl_ {
    ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
    mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
    ::object_detection::protos::Hyperparams* fc_hyperparams_;
    ::object_detection::protos::Hyperparams* conv_hyperparams_;
    bool use_dropout_;
    bool predict_instance_masks_;
    bool predict_keypoints_;
    bool masks_are_class_agnostic_;
    bool share_box_across_classes_;
    bool convolve_then_upsample_masks_;
    float dropout_keep_probability_;
    int32_t box_code_size_;
    int32_t mask_prediction_conv_depth_;
    int32_t mask_height_;
    int32_t mask_width_;
    int32_t mask_prediction_num_conv_layers_;
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto;
};
// -------------------------------------------------------------------

class RfcnBoxPredictor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:object_detection.protos.RfcnBoxPredictor) */ {
 public:
  inline RfcnBoxPredictor() : RfcnBoxPredictor(nullptr) {}
  ~RfcnBoxPredictor() override;
  explicit PROTOBUF_CONSTEXPR RfcnBoxPredictor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  RfcnBoxPredictor(const RfcnBoxPredictor& from);
  RfcnBoxPredictor(RfcnBoxPredictor&& from) noexcept
    : RfcnBoxPredictor() {
    *this = ::std::move(from);
  }

  inline RfcnBoxPredictor& operator=(const RfcnBoxPredictor& from) {
    CopyFrom(from);
    return *this;
  }
  inline RfcnBoxPredictor& operator=(RfcnBoxPredictor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const RfcnBoxPredictor& default_instance() {
    return *internal_default_instance();
  }
  static inline const RfcnBoxPredictor* internal_default_instance() {
    return reinterpret_cast<const RfcnBoxPredictor*>(
               &_RfcnBoxPredictor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    6;

  friend void swap(RfcnBoxPredictor& a, RfcnBoxPredictor& b) {
    a.Swap(&b);
  }
  inline void Swap(RfcnBoxPredictor* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(RfcnBoxPredictor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  RfcnBoxPredictor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<RfcnBoxPredictor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const RfcnBoxPredictor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom( const RfcnBoxPredictor& from) {
    RfcnBoxPredictor::MergeImpl(*this, from);
  }
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message& to_msg, const ::PROTOBUF_NAMESPACE_ID::Message& from_msg);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::PROTOBUF_NAMESPACE_ID::Arena* arena, bool is_message_owned);
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(RfcnBoxPredictor* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "object_detection.protos.RfcnBoxPredictor";
  }
  protected:
  explicit RfcnBoxPredictor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kConvHyperparamsFieldNumber = 1,
    kNumSpatialBinsHeightFieldNumber = 2,
    kNumSpatialBinsWidthFieldNumber = 3,
    kDepthFieldNumber = 4,
    kBoxCodeSizeFieldNumber = 5,
    kCropHeightFieldNumber = 6,
    kCropWidthFieldNumber = 7,
  };
  // optional .object_detection.protos.Hyperparams conv_hyperparams = 1;
  bool has_conv_hyperparams() const;
  private:
  bool _internal_has_conv_hyperparams() const;
  public:
  void clear_conv_hyperparams();
  const ::object_detection::protos::Hyperparams& conv_hyperparams() const;
  PROTOBUF_NODISCARD ::object_detection::protos::Hyperparams* release_conv_hyperparams();
  ::object_detection::protos::Hyperparams* mutable_conv_hyperparams();
  void set_allocated_conv_hyperparams(::object_detection::protos::Hyperparams* conv_hyperparams);
  private:
  const ::object_detection::protos::Hyperparams& _internal_conv_hyperparams() const;
  ::object_detection::protos::Hyperparams* _internal_mutable_conv_hyperparams();
  public:
  void unsafe_arena_set_allocated_conv_hyperparams(
      ::object_detection::protos::Hyperparams* conv_hyperparams);
  ::object_detection::protos::Hyperparams* unsafe_arena_release_conv_hyperparams();

  // optional int32 num_spatial_bins_height = 2 [default = 3];
  bool has_num_spatial_bins_height() const;
  private:
  bool _internal_has_num_spatial_bins_height() const;
  public:
  void clear_num_spatial_bins_height();
  int32_t num_spatial_bins_height() const;
  void set_num_spatial_bins_height(int32_t value);
  private:
  int32_t _internal_num_spatial_bins_height() const;
  void _internal_set_num_spatial_bins_height(int32_t value);
  public:

  // optional int32 num_spatial_bins_width = 3 [default = 3];
  bool has_num_spatial_bins_width() const;
  private:
  bool _internal_has_num_spatial_bins_width() const;
  public:
  void clear_num_spatial_bins_width();
  int32_t num_spatial_bins_width() const;
  void set_num_spatial_bins_width(int32_t value);
  private:
  int32_t _internal_num_spatial_bins_width() const;
  void _internal_set_num_spatial_bins_width(int32_t value);
  public:

  // optional int32 depth = 4 [default = 1024];
  bool has_depth() const;
  private:
  bool _internal_has_depth() const;
  public:
  void clear_depth();
  int32_t depth() const;
  void set_depth(int32_t value);
  private:
  int32_t _internal_depth() const;
  void _internal_set_depth(int32_t value);
  public:

  // optional int32 box_code_size = 5 [default = 4];
  bool has_box_code_size() const;
  private:
  bool _internal_has_box_code_size() const;
  public:
  void clear_box_code_size();
  int32_t box_code_size() const;
  void set_box_code_size(int32_t value);
  private:
  int32_t _internal_box_code_size() const;
  void _internal_set_box_code_size(int32_t value);
  public:

  // optional int32 crop_height = 6 [default = 12];
  bool has_crop_height() const;
  private:
  bool _internal_has_crop_height() const;
  public:
  void clear_crop_height();
  int32_t crop_height() const;
  void set_crop_height(int32_t value);
  private:
  int32_t _internal_crop_height() const;
  void _internal_set_crop_height(int32_t value);
  public:

  // optional int32 crop_width = 7 [default = 12];
  bool has_crop_width() const;
  private:
  bool _internal_has_crop_width() const;
  public:
  void clear_crop_width();
  int32_t crop_width() const;
  void set_crop_width(int32_t value);
  private:
  int32_t _internal_crop_width() const;
  void _internal_set_crop_width(int32_t value);
  public:

  // @@protoc_insertion_point(class_scope:object_detection.protos.RfcnBoxPredictor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  struct Impl_ {
    ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
    mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
    ::object_detection::protos::Hyperparams* conv_hyperparams_;
    int32_t num_spatial_bins_height_;
    int32_t num_spatial_bins_width_;
    int32_t depth_;
    int32_t box_code_size_;
    int32_t crop_height_;
    int32_t crop_width_;
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// BoxPredictor

// .object_detection.protos.ConvolutionalBoxPredictor convolutional_box_predictor = 1;
inline bool BoxPredictor::_internal_has_convolutional_box_predictor() const {
  return box_predictor_oneof_case() == kConvolutionalBoxPredictor;
}
inline bool BoxPredictor::has_convolutional_box_predictor() const {
  return _internal_has_convolutional_box_predictor();
}
inline void BoxPredictor::set_has_convolutional_box_predictor() {
  _impl_._oneof_case_[0] = kConvolutionalBoxPredictor;
}
inline void BoxPredictor::clear_convolutional_box_predictor() {
  if (_internal_has_convolutional_box_predictor()) {
    if (GetArenaForAllocation() == nullptr) {
      delete _impl_.box_predictor_oneof_.convolutional_box_predictor_;
    }
    clear_has_box_predictor_oneof();
  }
}
inline ::object_detection::protos::ConvolutionalBoxPredictor* BoxPredictor::release_convolutional_box_predictor() {
  // @@protoc_insertion_point(field_release:object_detection.protos.BoxPredictor.convolutional_box_predictor)
  if (_internal_has_convolutional_box_predictor()) {
    clear_has_box_predictor_oneof();
    ::object_detection::protos::ConvolutionalBoxPredictor* temp = _impl_.box_predictor_oneof_.convolutional_box_predictor_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    _impl_.box_predictor_oneof_.convolutional_box_predictor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::object_detection::protos::ConvolutionalBoxPredictor& BoxPredictor::_internal_convolutional_box_predictor() const {
  return _internal_has_convolutional_box_predictor()
      ? *_impl_.box_predictor_oneof_.convolutional_box_predictor_
      : reinterpret_cast< ::object_detection::protos::ConvolutionalBoxPredictor&>(::object_detection::protos::_ConvolutionalBoxPredictor_default_instance_);
}
inline const ::object_detection::protos::ConvolutionalBoxPredictor& BoxPredictor::convolutional_box_predictor() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.BoxPredictor.convolutional_box_predictor)
  return _internal_convolutional_box_predictor();
}
inline ::object_detection::protos::ConvolutionalBoxPredictor* BoxPredictor::unsafe_arena_release_convolutional_box_predictor() {
  // @@protoc_insertion_point(field_unsafe_arena_release:object_detection.protos.BoxPredictor.convolutional_box_predictor)
  if (_internal_has_convolutional_box_predictor()) {
    clear_has_box_predictor_oneof();
    ::object_detection::protos::ConvolutionalBoxPredictor* temp = _impl_.box_predictor_oneof_.convolutional_box_predictor_;
    _impl_.box_predictor_oneof_.convolutional_box_predictor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void BoxPredictor::unsafe_arena_set_allocated_convolutional_box_predictor(::object_detection::protos::ConvolutionalBoxPredictor* convolutional_box_predictor) {
  clear_box_predictor_oneof();
  if (convolutional_box_predictor) {
    set_has_convolutional_box_predictor();
    _impl_.box_predictor_oneof_.convolutional_box_predictor_ = convolutional_box_predictor;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.BoxPredictor.convolutional_box_predictor)
}
inline ::object_detection::protos::ConvolutionalBoxPredictor* BoxPredictor::_internal_mutable_convolutional_box_predictor() {
  if (!_internal_has_convolutional_box_predictor()) {
    clear_box_predictor_oneof();
    set_has_convolutional_box_predictor();
    _impl_.box_predictor_oneof_.convolutional_box_predictor_ = CreateMaybeMessage< ::object_detection::protos::ConvolutionalBoxPredictor >(GetArenaForAllocation());
  }
  return _impl_.box_predictor_oneof_.convolutional_box_predictor_;
}
inline ::object_detection::protos::ConvolutionalBoxPredictor* BoxPredictor::mutable_convolutional_box_predictor() {
  ::object_detection::protos::ConvolutionalBoxPredictor* _msg = _internal_mutable_convolutional_box_predictor();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.BoxPredictor.convolutional_box_predictor)
  return _msg;
}

// .object_detection.protos.MaskRCNNBoxPredictor mask_rcnn_box_predictor = 2;
inline bool BoxPredictor::_internal_has_mask_rcnn_box_predictor() const {
  return box_predictor_oneof_case() == kMaskRcnnBoxPredictor;
}
inline bool BoxPredictor::has_mask_rcnn_box_predictor() const {
  return _internal_has_mask_rcnn_box_predictor();
}
inline void BoxPredictor::set_has_mask_rcnn_box_predictor() {
  _impl_._oneof_case_[0] = kMaskRcnnBoxPredictor;
}
inline void BoxPredictor::clear_mask_rcnn_box_predictor() {
  if (_internal_has_mask_rcnn_box_predictor()) {
    if (GetArenaForAllocation() == nullptr) {
      delete _impl_.box_predictor_oneof_.mask_rcnn_box_predictor_;
    }
    clear_has_box_predictor_oneof();
  }
}
inline ::object_detection::protos::MaskRCNNBoxPredictor* BoxPredictor::release_mask_rcnn_box_predictor() {
  // @@protoc_insertion_point(field_release:object_detection.protos.BoxPredictor.mask_rcnn_box_predictor)
  if (_internal_has_mask_rcnn_box_predictor()) {
    clear_has_box_predictor_oneof();
    ::object_detection::protos::MaskRCNNBoxPredictor* temp = _impl_.box_predictor_oneof_.mask_rcnn_box_predictor_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    _impl_.box_predictor_oneof_.mask_rcnn_box_predictor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::object_detection::protos::MaskRCNNBoxPredictor& BoxPredictor::_internal_mask_rcnn_box_predictor() const {
  return _internal_has_mask_rcnn_box_predictor()
      ? *_impl_.box_predictor_oneof_.mask_rcnn_box_predictor_
      : reinterpret_cast< ::object_detection::protos::MaskRCNNBoxPredictor&>(::object_detection::protos::_MaskRCNNBoxPredictor_default_instance_);
}
inline const ::object_detection::protos::MaskRCNNBoxPredictor& BoxPredictor::mask_rcnn_box_predictor() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.BoxPredictor.mask_rcnn_box_predictor)
  return _internal_mask_rcnn_box_predictor();
}
inline ::object_detection::protos::MaskRCNNBoxPredictor* BoxPredictor::unsafe_arena_release_mask_rcnn_box_predictor() {
  // @@protoc_insertion_point(field_unsafe_arena_release:object_detection.protos.BoxPredictor.mask_rcnn_box_predictor)
  if (_internal_has_mask_rcnn_box_predictor()) {
    clear_has_box_predictor_oneof();
    ::object_detection::protos::MaskRCNNBoxPredictor* temp = _impl_.box_predictor_oneof_.mask_rcnn_box_predictor_;
    _impl_.box_predictor_oneof_.mask_rcnn_box_predictor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void BoxPredictor::unsafe_arena_set_allocated_mask_rcnn_box_predictor(::object_detection::protos::MaskRCNNBoxPredictor* mask_rcnn_box_predictor) {
  clear_box_predictor_oneof();
  if (mask_rcnn_box_predictor) {
    set_has_mask_rcnn_box_predictor();
    _impl_.box_predictor_oneof_.mask_rcnn_box_predictor_ = mask_rcnn_box_predictor;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.BoxPredictor.mask_rcnn_box_predictor)
}
inline ::object_detection::protos::MaskRCNNBoxPredictor* BoxPredictor::_internal_mutable_mask_rcnn_box_predictor() {
  if (!_internal_has_mask_rcnn_box_predictor()) {
    clear_box_predictor_oneof();
    set_has_mask_rcnn_box_predictor();
    _impl_.box_predictor_oneof_.mask_rcnn_box_predictor_ = CreateMaybeMessage< ::object_detection::protos::MaskRCNNBoxPredictor >(GetArenaForAllocation());
  }
  return _impl_.box_predictor_oneof_.mask_rcnn_box_predictor_;
}
inline ::object_detection::protos::MaskRCNNBoxPredictor* BoxPredictor::mutable_mask_rcnn_box_predictor() {
  ::object_detection::protos::MaskRCNNBoxPredictor* _msg = _internal_mutable_mask_rcnn_box_predictor();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.BoxPredictor.mask_rcnn_box_predictor)
  return _msg;
}

// .object_detection.protos.RfcnBoxPredictor rfcn_box_predictor = 3;
inline bool BoxPredictor::_internal_has_rfcn_box_predictor() const {
  return box_predictor_oneof_case() == kRfcnBoxPredictor;
}
inline bool BoxPredictor::has_rfcn_box_predictor() const {
  return _internal_has_rfcn_box_predictor();
}
inline void BoxPredictor::set_has_rfcn_box_predictor() {
  _impl_._oneof_case_[0] = kRfcnBoxPredictor;
}
inline void BoxPredictor::clear_rfcn_box_predictor() {
  if (_internal_has_rfcn_box_predictor()) {
    if (GetArenaForAllocation() == nullptr) {
      delete _impl_.box_predictor_oneof_.rfcn_box_predictor_;
    }
    clear_has_box_predictor_oneof();
  }
}
inline ::object_detection::protos::RfcnBoxPredictor* BoxPredictor::release_rfcn_box_predictor() {
  // @@protoc_insertion_point(field_release:object_detection.protos.BoxPredictor.rfcn_box_predictor)
  if (_internal_has_rfcn_box_predictor()) {
    clear_has_box_predictor_oneof();
    ::object_detection::protos::RfcnBoxPredictor* temp = _impl_.box_predictor_oneof_.rfcn_box_predictor_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    _impl_.box_predictor_oneof_.rfcn_box_predictor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::object_detection::protos::RfcnBoxPredictor& BoxPredictor::_internal_rfcn_box_predictor() const {
  return _internal_has_rfcn_box_predictor()
      ? *_impl_.box_predictor_oneof_.rfcn_box_predictor_
      : reinterpret_cast< ::object_detection::protos::RfcnBoxPredictor&>(::object_detection::protos::_RfcnBoxPredictor_default_instance_);
}
inline const ::object_detection::protos::RfcnBoxPredictor& BoxPredictor::rfcn_box_predictor() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.BoxPredictor.rfcn_box_predictor)
  return _internal_rfcn_box_predictor();
}
inline ::object_detection::protos::RfcnBoxPredictor* BoxPredictor::unsafe_arena_release_rfcn_box_predictor() {
  // @@protoc_insertion_point(field_unsafe_arena_release:object_detection.protos.BoxPredictor.rfcn_box_predictor)
  if (_internal_has_rfcn_box_predictor()) {
    clear_has_box_predictor_oneof();
    ::object_detection::protos::RfcnBoxPredictor* temp = _impl_.box_predictor_oneof_.rfcn_box_predictor_;
    _impl_.box_predictor_oneof_.rfcn_box_predictor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void BoxPredictor::unsafe_arena_set_allocated_rfcn_box_predictor(::object_detection::protos::RfcnBoxPredictor* rfcn_box_predictor) {
  clear_box_predictor_oneof();
  if (rfcn_box_predictor) {
    set_has_rfcn_box_predictor();
    _impl_.box_predictor_oneof_.rfcn_box_predictor_ = rfcn_box_predictor;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.BoxPredictor.rfcn_box_predictor)
}
inline ::object_detection::protos::RfcnBoxPredictor* BoxPredictor::_internal_mutable_rfcn_box_predictor() {
  if (!_internal_has_rfcn_box_predictor()) {
    clear_box_predictor_oneof();
    set_has_rfcn_box_predictor();
    _impl_.box_predictor_oneof_.rfcn_box_predictor_ = CreateMaybeMessage< ::object_detection::protos::RfcnBoxPredictor >(GetArenaForAllocation());
  }
  return _impl_.box_predictor_oneof_.rfcn_box_predictor_;
}
inline ::object_detection::protos::RfcnBoxPredictor* BoxPredictor::mutable_rfcn_box_predictor() {
  ::object_detection::protos::RfcnBoxPredictor* _msg = _internal_mutable_rfcn_box_predictor();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.BoxPredictor.rfcn_box_predictor)
  return _msg;
}

// .object_detection.protos.WeightSharedConvolutionalBoxPredictor weight_shared_convolutional_box_predictor = 4;
inline bool BoxPredictor::_internal_has_weight_shared_convolutional_box_predictor() const {
  return box_predictor_oneof_case() == kWeightSharedConvolutionalBoxPredictor;
}
inline bool BoxPredictor::has_weight_shared_convolutional_box_predictor() const {
  return _internal_has_weight_shared_convolutional_box_predictor();
}
inline void BoxPredictor::set_has_weight_shared_convolutional_box_predictor() {
  _impl_._oneof_case_[0] = kWeightSharedConvolutionalBoxPredictor;
}
inline void BoxPredictor::clear_weight_shared_convolutional_box_predictor() {
  if (_internal_has_weight_shared_convolutional_box_predictor()) {
    if (GetArenaForAllocation() == nullptr) {
      delete _impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_;
    }
    clear_has_box_predictor_oneof();
  }
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* BoxPredictor::release_weight_shared_convolutional_box_predictor() {
  // @@protoc_insertion_point(field_release:object_detection.protos.BoxPredictor.weight_shared_convolutional_box_predictor)
  if (_internal_has_weight_shared_convolutional_box_predictor()) {
    clear_has_box_predictor_oneof();
    ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* temp = _impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    _impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor& BoxPredictor::_internal_weight_shared_convolutional_box_predictor() const {
  return _internal_has_weight_shared_convolutional_box_predictor()
      ? *_impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_
      : reinterpret_cast< ::object_detection::protos::WeightSharedConvolutionalBoxPredictor&>(::object_detection::protos::_WeightSharedConvolutionalBoxPredictor_default_instance_);
}
inline const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor& BoxPredictor::weight_shared_convolutional_box_predictor() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.BoxPredictor.weight_shared_convolutional_box_predictor)
  return _internal_weight_shared_convolutional_box_predictor();
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* BoxPredictor::unsafe_arena_release_weight_shared_convolutional_box_predictor() {
  // @@protoc_insertion_point(field_unsafe_arena_release:object_detection.protos.BoxPredictor.weight_shared_convolutional_box_predictor)
  if (_internal_has_weight_shared_convolutional_box_predictor()) {
    clear_has_box_predictor_oneof();
    ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* temp = _impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_;
    _impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void BoxPredictor::unsafe_arena_set_allocated_weight_shared_convolutional_box_predictor(::object_detection::protos::WeightSharedConvolutionalBoxPredictor* weight_shared_convolutional_box_predictor) {
  clear_box_predictor_oneof();
  if (weight_shared_convolutional_box_predictor) {
    set_has_weight_shared_convolutional_box_predictor();
    _impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_ = weight_shared_convolutional_box_predictor;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.BoxPredictor.weight_shared_convolutional_box_predictor)
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* BoxPredictor::_internal_mutable_weight_shared_convolutional_box_predictor() {
  if (!_internal_has_weight_shared_convolutional_box_predictor()) {
    clear_box_predictor_oneof();
    set_has_weight_shared_convolutional_box_predictor();
    _impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_ = CreateMaybeMessage< ::object_detection::protos::WeightSharedConvolutionalBoxPredictor >(GetArenaForAllocation());
  }
  return _impl_.box_predictor_oneof_.weight_shared_convolutional_box_predictor_;
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* BoxPredictor::mutable_weight_shared_convolutional_box_predictor() {
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor* _msg = _internal_mutable_weight_shared_convolutional_box_predictor();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.BoxPredictor.weight_shared_convolutional_box_predictor)
  return _msg;
}

inline bool BoxPredictor::has_box_predictor_oneof() const {
  return box_predictor_oneof_case() != BOX_PREDICTOR_ONEOF_NOT_SET;
}
inline void BoxPredictor::clear_has_box_predictor_oneof() {
  _impl_._oneof_case_[0] = BOX_PREDICTOR_ONEOF_NOT_SET;
}
inline BoxPredictor::BoxPredictorOneofCase BoxPredictor::box_predictor_oneof_case() const {
  return BoxPredictor::BoxPredictorOneofCase(_impl_._oneof_case_[0]);
}
// -------------------------------------------------------------------

// ConvolutionalBoxPredictor_BoxEncodingsClipRange

// optional float min = 1;
inline bool ConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_has_min() const {
  bool value = (_impl_._has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor_BoxEncodingsClipRange::has_min() const {
  return _internal_has_min();
}
inline void ConvolutionalBoxPredictor_BoxEncodingsClipRange::clear_min() {
  _impl_.min_ = 0;
  _impl_._has_bits_[0] &= ~0x00000001u;
}
inline float ConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_min() const {
  return _impl_.min_;
}
inline float ConvolutionalBoxPredictor_BoxEncodingsClipRange::min() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange.min)
  return _internal_min();
}
inline void ConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_set_min(float value) {
  _impl_._has_bits_[0] |= 0x00000001u;
  _impl_.min_ = value;
}
inline void ConvolutionalBoxPredictor_BoxEncodingsClipRange::set_min(float value) {
  _internal_set_min(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange.min)
}

// optional float max = 2;
inline bool ConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_has_max() const {
  bool value = (_impl_._has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor_BoxEncodingsClipRange::has_max() const {
  return _internal_has_max();
}
inline void ConvolutionalBoxPredictor_BoxEncodingsClipRange::clear_max() {
  _impl_.max_ = 0;
  _impl_._has_bits_[0] &= ~0x00000002u;
}
inline float ConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_max() const {
  return _impl_.max_;
}
inline float ConvolutionalBoxPredictor_BoxEncodingsClipRange::max() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange.max)
  return _internal_max();
}
inline void ConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_set_max(float value) {
  _impl_._has_bits_[0] |= 0x00000002u;
  _impl_.max_ = value;
}
inline void ConvolutionalBoxPredictor_BoxEncodingsClipRange::set_max(float value) {
  _internal_set_max(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange.max)
}

// -------------------------------------------------------------------

// ConvolutionalBoxPredictor

// optional .object_detection.protos.Hyperparams conv_hyperparams = 1;
inline bool ConvolutionalBoxPredictor::_internal_has_conv_hyperparams() const {
  bool value = (_impl_._has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || _impl_.conv_hyperparams_ != nullptr);
  return value;
}
inline bool ConvolutionalBoxPredictor::has_conv_hyperparams() const {
  return _internal_has_conv_hyperparams();
}
inline const ::object_detection::protos::Hyperparams& ConvolutionalBoxPredictor::_internal_conv_hyperparams() const {
  const ::object_detection::protos::Hyperparams* p = _impl_.conv_hyperparams_;
  return p != nullptr ? *p : reinterpret_cast<const ::object_detection::protos::Hyperparams&>(
      ::object_detection::protos::_Hyperparams_default_instance_);
}
inline const ::object_detection::protos::Hyperparams& ConvolutionalBoxPredictor::conv_hyperparams() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.conv_hyperparams)
  return _internal_conv_hyperparams();
}
inline void ConvolutionalBoxPredictor::unsafe_arena_set_allocated_conv_hyperparams(
    ::object_detection::protos::Hyperparams* conv_hyperparams) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.conv_hyperparams_);
  }
  _impl_.conv_hyperparams_ = conv_hyperparams;
  if (conv_hyperparams) {
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.ConvolutionalBoxPredictor.conv_hyperparams)
}
inline ::object_detection::protos::Hyperparams* ConvolutionalBoxPredictor::release_conv_hyperparams() {
  _impl_._has_bits_[0] &= ~0x00000001u;
  ::object_detection::protos::Hyperparams* temp = _impl_.conv_hyperparams_;
  _impl_.conv_hyperparams_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::object_detection::protos::Hyperparams* ConvolutionalBoxPredictor::unsafe_arena_release_conv_hyperparams() {
  // @@protoc_insertion_point(field_release:object_detection.protos.ConvolutionalBoxPredictor.conv_hyperparams)
  _impl_._has_bits_[0] &= ~0x00000001u;
  ::object_detection::protos::Hyperparams* temp = _impl_.conv_hyperparams_;
  _impl_.conv_hyperparams_ = nullptr;
  return temp;
}
inline ::object_detection::protos::Hyperparams* ConvolutionalBoxPredictor::_internal_mutable_conv_hyperparams() {
  _impl_._has_bits_[0] |= 0x00000001u;
  if (_impl_.conv_hyperparams_ == nullptr) {
    auto* p = CreateMaybeMessage<::object_detection::protos::Hyperparams>(GetArenaForAllocation());
    _impl_.conv_hyperparams_ = p;
  }
  return _impl_.conv_hyperparams_;
}
inline ::object_detection::protos::Hyperparams* ConvolutionalBoxPredictor::mutable_conv_hyperparams() {
  ::object_detection::protos::Hyperparams* _msg = _internal_mutable_conv_hyperparams();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.ConvolutionalBoxPredictor.conv_hyperparams)
  return _msg;
}
inline void ConvolutionalBoxPredictor::set_allocated_conv_hyperparams(::object_detection::protos::Hyperparams* conv_hyperparams) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.conv_hyperparams_);
  }
  if (conv_hyperparams) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(conv_hyperparams));
    if (message_arena != submessage_arena) {
      conv_hyperparams = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, conv_hyperparams, submessage_arena);
    }
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  _impl_.conv_hyperparams_ = conv_hyperparams;
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.ConvolutionalBoxPredictor.conv_hyperparams)
}

// optional int32 min_depth = 2 [default = 0];
inline bool ConvolutionalBoxPredictor::_internal_has_min_depth() const {
  bool value = (_impl_._has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_min_depth() const {
  return _internal_has_min_depth();
}
inline void ConvolutionalBoxPredictor::clear_min_depth() {
  _impl_.min_depth_ = 0;
  _impl_._has_bits_[0] &= ~0x00000004u;
}
inline int32_t ConvolutionalBoxPredictor::_internal_min_depth() const {
  return _impl_.min_depth_;
}
inline int32_t ConvolutionalBoxPredictor::min_depth() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.min_depth)
  return _internal_min_depth();
}
inline void ConvolutionalBoxPredictor::_internal_set_min_depth(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000004u;
  _impl_.min_depth_ = value;
}
inline void ConvolutionalBoxPredictor::set_min_depth(int32_t value) {
  _internal_set_min_depth(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.min_depth)
}

// optional int32 max_depth = 3 [default = 0];
inline bool ConvolutionalBoxPredictor::_internal_has_max_depth() const {
  bool value = (_impl_._has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_max_depth() const {
  return _internal_has_max_depth();
}
inline void ConvolutionalBoxPredictor::clear_max_depth() {
  _impl_.max_depth_ = 0;
  _impl_._has_bits_[0] &= ~0x00000008u;
}
inline int32_t ConvolutionalBoxPredictor::_internal_max_depth() const {
  return _impl_.max_depth_;
}
inline int32_t ConvolutionalBoxPredictor::max_depth() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.max_depth)
  return _internal_max_depth();
}
inline void ConvolutionalBoxPredictor::_internal_set_max_depth(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000008u;
  _impl_.max_depth_ = value;
}
inline void ConvolutionalBoxPredictor::set_max_depth(int32_t value) {
  _internal_set_max_depth(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.max_depth)
}

// optional int32 num_layers_before_predictor = 4 [default = 0];
inline bool ConvolutionalBoxPredictor::_internal_has_num_layers_before_predictor() const {
  bool value = (_impl_._has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_num_layers_before_predictor() const {
  return _internal_has_num_layers_before_predictor();
}
inline void ConvolutionalBoxPredictor::clear_num_layers_before_predictor() {
  _impl_.num_layers_before_predictor_ = 0;
  _impl_._has_bits_[0] &= ~0x00000010u;
}
inline int32_t ConvolutionalBoxPredictor::_internal_num_layers_before_predictor() const {
  return _impl_.num_layers_before_predictor_;
}
inline int32_t ConvolutionalBoxPredictor::num_layers_before_predictor() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.num_layers_before_predictor)
  return _internal_num_layers_before_predictor();
}
inline void ConvolutionalBoxPredictor::_internal_set_num_layers_before_predictor(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000010u;
  _impl_.num_layers_before_predictor_ = value;
}
inline void ConvolutionalBoxPredictor::set_num_layers_before_predictor(int32_t value) {
  _internal_set_num_layers_before_predictor(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.num_layers_before_predictor)
}

// optional bool use_dropout = 5 [default = true];
inline bool ConvolutionalBoxPredictor::_internal_has_use_dropout() const {
  bool value = (_impl_._has_bits_[0] & 0x00000100u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_use_dropout() const {
  return _internal_has_use_dropout();
}
inline void ConvolutionalBoxPredictor::clear_use_dropout() {
  _impl_.use_dropout_ = true;
  _impl_._has_bits_[0] &= ~0x00000100u;
}
inline bool ConvolutionalBoxPredictor::_internal_use_dropout() const {
  return _impl_.use_dropout_;
}
inline bool ConvolutionalBoxPredictor::use_dropout() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.use_dropout)
  return _internal_use_dropout();
}
inline void ConvolutionalBoxPredictor::_internal_set_use_dropout(bool value) {
  _impl_._has_bits_[0] |= 0x00000100u;
  _impl_.use_dropout_ = value;
}
inline void ConvolutionalBoxPredictor::set_use_dropout(bool value) {
  _internal_set_use_dropout(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.use_dropout)
}

// optional float dropout_keep_probability = 6 [default = 0.8];
inline bool ConvolutionalBoxPredictor::_internal_has_dropout_keep_probability() const {
  bool value = (_impl_._has_bits_[0] & 0x00000200u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_dropout_keep_probability() const {
  return _internal_has_dropout_keep_probability();
}
inline void ConvolutionalBoxPredictor::clear_dropout_keep_probability() {
  _impl_.dropout_keep_probability_ = 0.8f;
  _impl_._has_bits_[0] &= ~0x00000200u;
}
inline float ConvolutionalBoxPredictor::_internal_dropout_keep_probability() const {
  return _impl_.dropout_keep_probability_;
}
inline float ConvolutionalBoxPredictor::dropout_keep_probability() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.dropout_keep_probability)
  return _internal_dropout_keep_probability();
}
inline void ConvolutionalBoxPredictor::_internal_set_dropout_keep_probability(float value) {
  _impl_._has_bits_[0] |= 0x00000200u;
  _impl_.dropout_keep_probability_ = value;
}
inline void ConvolutionalBoxPredictor::set_dropout_keep_probability(float value) {
  _internal_set_dropout_keep_probability(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.dropout_keep_probability)
}

// optional int32 kernel_size = 7 [default = 1];
inline bool ConvolutionalBoxPredictor::_internal_has_kernel_size() const {
  bool value = (_impl_._has_bits_[0] & 0x00000400u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_kernel_size() const {
  return _internal_has_kernel_size();
}
inline void ConvolutionalBoxPredictor::clear_kernel_size() {
  _impl_.kernel_size_ = 1;
  _impl_._has_bits_[0] &= ~0x00000400u;
}
inline int32_t ConvolutionalBoxPredictor::_internal_kernel_size() const {
  return _impl_.kernel_size_;
}
inline int32_t ConvolutionalBoxPredictor::kernel_size() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.kernel_size)
  return _internal_kernel_size();
}
inline void ConvolutionalBoxPredictor::_internal_set_kernel_size(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000400u;
  _impl_.kernel_size_ = value;
}
inline void ConvolutionalBoxPredictor::set_kernel_size(int32_t value) {
  _internal_set_kernel_size(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.kernel_size)
}

// optional int32 box_code_size = 8 [default = 4];
inline bool ConvolutionalBoxPredictor::_internal_has_box_code_size() const {
  bool value = (_impl_._has_bits_[0] & 0x00000800u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_box_code_size() const {
  return _internal_has_box_code_size();
}
inline void ConvolutionalBoxPredictor::clear_box_code_size() {
  _impl_.box_code_size_ = 4;
  _impl_._has_bits_[0] &= ~0x00000800u;
}
inline int32_t ConvolutionalBoxPredictor::_internal_box_code_size() const {
  return _impl_.box_code_size_;
}
inline int32_t ConvolutionalBoxPredictor::box_code_size() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.box_code_size)
  return _internal_box_code_size();
}
inline void ConvolutionalBoxPredictor::_internal_set_box_code_size(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000800u;
  _impl_.box_code_size_ = value;
}
inline void ConvolutionalBoxPredictor::set_box_code_size(int32_t value) {
  _internal_set_box_code_size(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.box_code_size)
}

// optional bool apply_sigmoid_to_scores = 9 [default = false];
inline bool ConvolutionalBoxPredictor::_internal_has_apply_sigmoid_to_scores() const {
  bool value = (_impl_._has_bits_[0] & 0x00000040u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_apply_sigmoid_to_scores() const {
  return _internal_has_apply_sigmoid_to_scores();
}
inline void ConvolutionalBoxPredictor::clear_apply_sigmoid_to_scores() {
  _impl_.apply_sigmoid_to_scores_ = false;
  _impl_._has_bits_[0] &= ~0x00000040u;
}
inline bool ConvolutionalBoxPredictor::_internal_apply_sigmoid_to_scores() const {
  return _impl_.apply_sigmoid_to_scores_;
}
inline bool ConvolutionalBoxPredictor::apply_sigmoid_to_scores() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.apply_sigmoid_to_scores)
  return _internal_apply_sigmoid_to_scores();
}
inline void ConvolutionalBoxPredictor::_internal_set_apply_sigmoid_to_scores(bool value) {
  _impl_._has_bits_[0] |= 0x00000040u;
  _impl_.apply_sigmoid_to_scores_ = value;
}
inline void ConvolutionalBoxPredictor::set_apply_sigmoid_to_scores(bool value) {
  _internal_set_apply_sigmoid_to_scores(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.apply_sigmoid_to_scores)
}

// optional float class_prediction_bias_init = 10 [default = 0];
inline bool ConvolutionalBoxPredictor::_internal_has_class_prediction_bias_init() const {
  bool value = (_impl_._has_bits_[0] & 0x00000020u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_class_prediction_bias_init() const {
  return _internal_has_class_prediction_bias_init();
}
inline void ConvolutionalBoxPredictor::clear_class_prediction_bias_init() {
  _impl_.class_prediction_bias_init_ = 0;
  _impl_._has_bits_[0] &= ~0x00000020u;
}
inline float ConvolutionalBoxPredictor::_internal_class_prediction_bias_init() const {
  return _impl_.class_prediction_bias_init_;
}
inline float ConvolutionalBoxPredictor::class_prediction_bias_init() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.class_prediction_bias_init)
  return _internal_class_prediction_bias_init();
}
inline void ConvolutionalBoxPredictor::_internal_set_class_prediction_bias_init(float value) {
  _impl_._has_bits_[0] |= 0x00000020u;
  _impl_.class_prediction_bias_init_ = value;
}
inline void ConvolutionalBoxPredictor::set_class_prediction_bias_init(float value) {
  _internal_set_class_prediction_bias_init(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.class_prediction_bias_init)
}

// optional bool use_depthwise = 11 [default = false];
inline bool ConvolutionalBoxPredictor::_internal_has_use_depthwise() const {
  bool value = (_impl_._has_bits_[0] & 0x00000080u) != 0;
  return value;
}
inline bool ConvolutionalBoxPredictor::has_use_depthwise() const {
  return _internal_has_use_depthwise();
}
inline void ConvolutionalBoxPredictor::clear_use_depthwise() {
  _impl_.use_depthwise_ = false;
  _impl_._has_bits_[0] &= ~0x00000080u;
}
inline bool ConvolutionalBoxPredictor::_internal_use_depthwise() const {
  return _impl_.use_depthwise_;
}
inline bool ConvolutionalBoxPredictor::use_depthwise() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.use_depthwise)
  return _internal_use_depthwise();
}
inline void ConvolutionalBoxPredictor::_internal_set_use_depthwise(bool value) {
  _impl_._has_bits_[0] |= 0x00000080u;
  _impl_.use_depthwise_ = value;
}
inline void ConvolutionalBoxPredictor::set_use_depthwise(bool value) {
  _internal_set_use_depthwise(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.ConvolutionalBoxPredictor.use_depthwise)
}

// optional .object_detection.protos.ConvolutionalBoxPredictor.BoxEncodingsClipRange box_encodings_clip_range = 12;
inline bool ConvolutionalBoxPredictor::_internal_has_box_encodings_clip_range() const {
  bool value = (_impl_._has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || _impl_.box_encodings_clip_range_ != nullptr);
  return value;
}
inline bool ConvolutionalBoxPredictor::has_box_encodings_clip_range() const {
  return _internal_has_box_encodings_clip_range();
}
inline void ConvolutionalBoxPredictor::clear_box_encodings_clip_range() {
  if (_impl_.box_encodings_clip_range_ != nullptr) _impl_.box_encodings_clip_range_->Clear();
  _impl_._has_bits_[0] &= ~0x00000002u;
}
inline const ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange& ConvolutionalBoxPredictor::_internal_box_encodings_clip_range() const {
  const ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* p = _impl_.box_encodings_clip_range_;
  return p != nullptr ? *p : reinterpret_cast<const ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange&>(
      ::object_detection::protos::_ConvolutionalBoxPredictor_BoxEncodingsClipRange_default_instance_);
}
inline const ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange& ConvolutionalBoxPredictor::box_encodings_clip_range() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.ConvolutionalBoxPredictor.box_encodings_clip_range)
  return _internal_box_encodings_clip_range();
}
inline void ConvolutionalBoxPredictor::unsafe_arena_set_allocated_box_encodings_clip_range(
    ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.box_encodings_clip_range_);
  }
  _impl_.box_encodings_clip_range_ = box_encodings_clip_range;
  if (box_encodings_clip_range) {
    _impl_._has_bits_[0] |= 0x00000002u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.ConvolutionalBoxPredictor.box_encodings_clip_range)
}
inline ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* ConvolutionalBoxPredictor::release_box_encodings_clip_range() {
  _impl_._has_bits_[0] &= ~0x00000002u;
  ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* temp = _impl_.box_encodings_clip_range_;
  _impl_.box_encodings_clip_range_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* ConvolutionalBoxPredictor::unsafe_arena_release_box_encodings_clip_range() {
  // @@protoc_insertion_point(field_release:object_detection.protos.ConvolutionalBoxPredictor.box_encodings_clip_range)
  _impl_._has_bits_[0] &= ~0x00000002u;
  ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* temp = _impl_.box_encodings_clip_range_;
  _impl_.box_encodings_clip_range_ = nullptr;
  return temp;
}
inline ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* ConvolutionalBoxPredictor::_internal_mutable_box_encodings_clip_range() {
  _impl_._has_bits_[0] |= 0x00000002u;
  if (_impl_.box_encodings_clip_range_ == nullptr) {
    auto* p = CreateMaybeMessage<::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange>(GetArenaForAllocation());
    _impl_.box_encodings_clip_range_ = p;
  }
  return _impl_.box_encodings_clip_range_;
}
inline ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* ConvolutionalBoxPredictor::mutable_box_encodings_clip_range() {
  ::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* _msg = _internal_mutable_box_encodings_clip_range();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.ConvolutionalBoxPredictor.box_encodings_clip_range)
  return _msg;
}
inline void ConvolutionalBoxPredictor::set_allocated_box_encodings_clip_range(::object_detection::protos::ConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete _impl_.box_encodings_clip_range_;
  }
  if (box_encodings_clip_range) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(box_encodings_clip_range);
    if (message_arena != submessage_arena) {
      box_encodings_clip_range = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, box_encodings_clip_range, submessage_arena);
    }
    _impl_._has_bits_[0] |= 0x00000002u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000002u;
  }
  _impl_.box_encodings_clip_range_ = box_encodings_clip_range;
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.ConvolutionalBoxPredictor.box_encodings_clip_range)
}

// -------------------------------------------------------------------

// WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange

// optional float min = 1;
inline bool WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_has_min() const {
  bool value = (_impl_._has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::has_min() const {
  return _internal_has_min();
}
inline void WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::clear_min() {
  _impl_.min_ = 0;
  _impl_._has_bits_[0] &= ~0x00000001u;
}
inline float WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_min() const {
  return _impl_.min_;
}
inline float WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::min() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange.min)
  return _internal_min();
}
inline void WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_set_min(float value) {
  _impl_._has_bits_[0] |= 0x00000001u;
  _impl_.min_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::set_min(float value) {
  _internal_set_min(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange.min)
}

// optional float max = 2;
inline bool WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_has_max() const {
  bool value = (_impl_._has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::has_max() const {
  return _internal_has_max();
}
inline void WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::clear_max() {
  _impl_.max_ = 0;
  _impl_._has_bits_[0] &= ~0x00000002u;
}
inline float WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_max() const {
  return _impl_.max_;
}
inline float WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::max() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange.max)
  return _internal_max();
}
inline void WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::_internal_set_max(float value) {
  _impl_._has_bits_[0] |= 0x00000002u;
  _impl_.max_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange::set_max(float value) {
  _internal_set_max(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange.max)
}

// -------------------------------------------------------------------

// WeightSharedConvolutionalBoxPredictor

// optional .object_detection.protos.Hyperparams conv_hyperparams = 1;
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_conv_hyperparams() const {
  bool value = (_impl_._has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || _impl_.conv_hyperparams_ != nullptr);
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_conv_hyperparams() const {
  return _internal_has_conv_hyperparams();
}
inline const ::object_detection::protos::Hyperparams& WeightSharedConvolutionalBoxPredictor::_internal_conv_hyperparams() const {
  const ::object_detection::protos::Hyperparams* p = _impl_.conv_hyperparams_;
  return p != nullptr ? *p : reinterpret_cast<const ::object_detection::protos::Hyperparams&>(
      ::object_detection::protos::_Hyperparams_default_instance_);
}
inline const ::object_detection::protos::Hyperparams& WeightSharedConvolutionalBoxPredictor::conv_hyperparams() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.conv_hyperparams)
  return _internal_conv_hyperparams();
}
inline void WeightSharedConvolutionalBoxPredictor::unsafe_arena_set_allocated_conv_hyperparams(
    ::object_detection::protos::Hyperparams* conv_hyperparams) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.conv_hyperparams_);
  }
  _impl_.conv_hyperparams_ = conv_hyperparams;
  if (conv_hyperparams) {
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.WeightSharedConvolutionalBoxPredictor.conv_hyperparams)
}
inline ::object_detection::protos::Hyperparams* WeightSharedConvolutionalBoxPredictor::release_conv_hyperparams() {
  _impl_._has_bits_[0] &= ~0x00000001u;
  ::object_detection::protos::Hyperparams* temp = _impl_.conv_hyperparams_;
  _impl_.conv_hyperparams_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::object_detection::protos::Hyperparams* WeightSharedConvolutionalBoxPredictor::unsafe_arena_release_conv_hyperparams() {
  // @@protoc_insertion_point(field_release:object_detection.protos.WeightSharedConvolutionalBoxPredictor.conv_hyperparams)
  _impl_._has_bits_[0] &= ~0x00000001u;
  ::object_detection::protos::Hyperparams* temp = _impl_.conv_hyperparams_;
  _impl_.conv_hyperparams_ = nullptr;
  return temp;
}
inline ::object_detection::protos::Hyperparams* WeightSharedConvolutionalBoxPredictor::_internal_mutable_conv_hyperparams() {
  _impl_._has_bits_[0] |= 0x00000001u;
  if (_impl_.conv_hyperparams_ == nullptr) {
    auto* p = CreateMaybeMessage<::object_detection::protos::Hyperparams>(GetArenaForAllocation());
    _impl_.conv_hyperparams_ = p;
  }
  return _impl_.conv_hyperparams_;
}
inline ::object_detection::protos::Hyperparams* WeightSharedConvolutionalBoxPredictor::mutable_conv_hyperparams() {
  ::object_detection::protos::Hyperparams* _msg = _internal_mutable_conv_hyperparams();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.WeightSharedConvolutionalBoxPredictor.conv_hyperparams)
  return _msg;
}
inline void WeightSharedConvolutionalBoxPredictor::set_allocated_conv_hyperparams(::object_detection::protos::Hyperparams* conv_hyperparams) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.conv_hyperparams_);
  }
  if (conv_hyperparams) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(conv_hyperparams));
    if (message_arena != submessage_arena) {
      conv_hyperparams = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, conv_hyperparams, submessage_arena);
    }
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  _impl_.conv_hyperparams_ = conv_hyperparams;
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.WeightSharedConvolutionalBoxPredictor.conv_hyperparams)
}

// optional int32 num_layers_before_predictor = 4 [default = 0];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_num_layers_before_predictor() const {
  bool value = (_impl_._has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_num_layers_before_predictor() const {
  return _internal_has_num_layers_before_predictor();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_num_layers_before_predictor() {
  _impl_.num_layers_before_predictor_ = 0;
  _impl_._has_bits_[0] &= ~0x00000008u;
}
inline int32_t WeightSharedConvolutionalBoxPredictor::_internal_num_layers_before_predictor() const {
  return _impl_.num_layers_before_predictor_;
}
inline int32_t WeightSharedConvolutionalBoxPredictor::num_layers_before_predictor() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.num_layers_before_predictor)
  return _internal_num_layers_before_predictor();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_num_layers_before_predictor(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000008u;
  _impl_.num_layers_before_predictor_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_num_layers_before_predictor(int32_t value) {
  _internal_set_num_layers_before_predictor(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.num_layers_before_predictor)
}

// optional int32 depth = 2 [default = 0];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_depth() const {
  bool value = (_impl_._has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_depth() const {
  return _internal_has_depth();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_depth() {
  _impl_.depth_ = 0;
  _impl_._has_bits_[0] &= ~0x00000004u;
}
inline int32_t WeightSharedConvolutionalBoxPredictor::_internal_depth() const {
  return _impl_.depth_;
}
inline int32_t WeightSharedConvolutionalBoxPredictor::depth() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.depth)
  return _internal_depth();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_depth(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000004u;
  _impl_.depth_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_depth(int32_t value) {
  _internal_set_depth(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.depth)
}

// optional int32 kernel_size = 7 [default = 3];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_kernel_size() const {
  bool value = (_impl_._has_bits_[0] & 0x00000400u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_kernel_size() const {
  return _internal_has_kernel_size();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_kernel_size() {
  _impl_.kernel_size_ = 3;
  _impl_._has_bits_[0] &= ~0x00000400u;
}
inline int32_t WeightSharedConvolutionalBoxPredictor::_internal_kernel_size() const {
  return _impl_.kernel_size_;
}
inline int32_t WeightSharedConvolutionalBoxPredictor::kernel_size() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.kernel_size)
  return _internal_kernel_size();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_kernel_size(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000400u;
  _impl_.kernel_size_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_kernel_size(int32_t value) {
  _internal_set_kernel_size(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.kernel_size)
}

// optional int32 box_code_size = 8 [default = 4];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_box_code_size() const {
  bool value = (_impl_._has_bits_[0] & 0x00000800u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_box_code_size() const {
  return _internal_has_box_code_size();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_box_code_size() {
  _impl_.box_code_size_ = 4;
  _impl_._has_bits_[0] &= ~0x00000800u;
}
inline int32_t WeightSharedConvolutionalBoxPredictor::_internal_box_code_size() const {
  return _impl_.box_code_size_;
}
inline int32_t WeightSharedConvolutionalBoxPredictor::box_code_size() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.box_code_size)
  return _internal_box_code_size();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_box_code_size(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000800u;
  _impl_.box_code_size_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_box_code_size(int32_t value) {
  _internal_set_box_code_size(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.box_code_size)
}

// optional float class_prediction_bias_init = 10 [default = 0];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_class_prediction_bias_init() const {
  bool value = (_impl_._has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_class_prediction_bias_init() const {
  return _internal_has_class_prediction_bias_init();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_class_prediction_bias_init() {
  _impl_.class_prediction_bias_init_ = 0;
  _impl_._has_bits_[0] &= ~0x00000010u;
}
inline float WeightSharedConvolutionalBoxPredictor::_internal_class_prediction_bias_init() const {
  return _impl_.class_prediction_bias_init_;
}
inline float WeightSharedConvolutionalBoxPredictor::class_prediction_bias_init() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.class_prediction_bias_init)
  return _internal_class_prediction_bias_init();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_class_prediction_bias_init(float value) {
  _impl_._has_bits_[0] |= 0x00000010u;
  _impl_.class_prediction_bias_init_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_class_prediction_bias_init(float value) {
  _internal_set_class_prediction_bias_init(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.class_prediction_bias_init)
}

// optional bool use_dropout = 11 [default = false];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_use_dropout() const {
  bool value = (_impl_._has_bits_[0] & 0x00000020u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_use_dropout() const {
  return _internal_has_use_dropout();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_use_dropout() {
  _impl_.use_dropout_ = false;
  _impl_._has_bits_[0] &= ~0x00000020u;
}
inline bool WeightSharedConvolutionalBoxPredictor::_internal_use_dropout() const {
  return _impl_.use_dropout_;
}
inline bool WeightSharedConvolutionalBoxPredictor::use_dropout() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.use_dropout)
  return _internal_use_dropout();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_use_dropout(bool value) {
  _impl_._has_bits_[0] |= 0x00000020u;
  _impl_.use_dropout_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_use_dropout(bool value) {
  _internal_set_use_dropout(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.use_dropout)
}

// optional float dropout_keep_probability = 12 [default = 0.8];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_dropout_keep_probability() const {
  bool value = (_impl_._has_bits_[0] & 0x00000200u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_dropout_keep_probability() const {
  return _internal_has_dropout_keep_probability();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_dropout_keep_probability() {
  _impl_.dropout_keep_probability_ = 0.8f;
  _impl_._has_bits_[0] &= ~0x00000200u;
}
inline float WeightSharedConvolutionalBoxPredictor::_internal_dropout_keep_probability() const {
  return _impl_.dropout_keep_probability_;
}
inline float WeightSharedConvolutionalBoxPredictor::dropout_keep_probability() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.dropout_keep_probability)
  return _internal_dropout_keep_probability();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_dropout_keep_probability(float value) {
  _impl_._has_bits_[0] |= 0x00000200u;
  _impl_.dropout_keep_probability_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_dropout_keep_probability(float value) {
  _internal_set_dropout_keep_probability(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.dropout_keep_probability)
}

// optional bool share_prediction_tower = 13 [default = false];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_share_prediction_tower() const {
  bool value = (_impl_._has_bits_[0] & 0x00000040u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_share_prediction_tower() const {
  return _internal_has_share_prediction_tower();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_share_prediction_tower() {
  _impl_.share_prediction_tower_ = false;
  _impl_._has_bits_[0] &= ~0x00000040u;
}
inline bool WeightSharedConvolutionalBoxPredictor::_internal_share_prediction_tower() const {
  return _impl_.share_prediction_tower_;
}
inline bool WeightSharedConvolutionalBoxPredictor::share_prediction_tower() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.share_prediction_tower)
  return _internal_share_prediction_tower();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_share_prediction_tower(bool value) {
  _impl_._has_bits_[0] |= 0x00000040u;
  _impl_.share_prediction_tower_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_share_prediction_tower(bool value) {
  _internal_set_share_prediction_tower(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.share_prediction_tower)
}

// optional bool use_depthwise = 14 [default = false];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_use_depthwise() const {
  bool value = (_impl_._has_bits_[0] & 0x00000080u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_use_depthwise() const {
  return _internal_has_use_depthwise();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_use_depthwise() {
  _impl_.use_depthwise_ = false;
  _impl_._has_bits_[0] &= ~0x00000080u;
}
inline bool WeightSharedConvolutionalBoxPredictor::_internal_use_depthwise() const {
  return _impl_.use_depthwise_;
}
inline bool WeightSharedConvolutionalBoxPredictor::use_depthwise() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.use_depthwise)
  return _internal_use_depthwise();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_use_depthwise(bool value) {
  _impl_._has_bits_[0] |= 0x00000080u;
  _impl_.use_depthwise_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_use_depthwise(bool value) {
  _internal_set_use_depthwise(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.use_depthwise)
}

// optional .object_detection.protos.WeightSharedConvolutionalBoxPredictor.ScoreConverter score_converter = 16 [default = IDENTITY];
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_score_converter() const {
  bool value = (_impl_._has_bits_[0] & 0x00000100u) != 0;
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_score_converter() const {
  return _internal_has_score_converter();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_score_converter() {
  _impl_.score_converter_ = 0;
  _impl_._has_bits_[0] &= ~0x00000100u;
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter WeightSharedConvolutionalBoxPredictor::_internal_score_converter() const {
  return static_cast< ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter >(_impl_.score_converter_);
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter WeightSharedConvolutionalBoxPredictor::score_converter() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.score_converter)
  return _internal_score_converter();
}
inline void WeightSharedConvolutionalBoxPredictor::_internal_set_score_converter(::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter value) {
  assert(::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter_IsValid(value));
  _impl_._has_bits_[0] |= 0x00000100u;
  _impl_.score_converter_ = value;
}
inline void WeightSharedConvolutionalBoxPredictor::set_score_converter(::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter value) {
  _internal_set_score_converter(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.WeightSharedConvolutionalBoxPredictor.score_converter)
}

// optional .object_detection.protos.WeightSharedConvolutionalBoxPredictor.BoxEncodingsClipRange box_encodings_clip_range = 17;
inline bool WeightSharedConvolutionalBoxPredictor::_internal_has_box_encodings_clip_range() const {
  bool value = (_impl_._has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || _impl_.box_encodings_clip_range_ != nullptr);
  return value;
}
inline bool WeightSharedConvolutionalBoxPredictor::has_box_encodings_clip_range() const {
  return _internal_has_box_encodings_clip_range();
}
inline void WeightSharedConvolutionalBoxPredictor::clear_box_encodings_clip_range() {
  if (_impl_.box_encodings_clip_range_ != nullptr) _impl_.box_encodings_clip_range_->Clear();
  _impl_._has_bits_[0] &= ~0x00000002u;
}
inline const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& WeightSharedConvolutionalBoxPredictor::_internal_box_encodings_clip_range() const {
  const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* p = _impl_.box_encodings_clip_range_;
  return p != nullptr ? *p : reinterpret_cast<const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange&>(
      ::object_detection::protos::_WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange_default_instance_);
}
inline const ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange& WeightSharedConvolutionalBoxPredictor::box_encodings_clip_range() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.WeightSharedConvolutionalBoxPredictor.box_encodings_clip_range)
  return _internal_box_encodings_clip_range();
}
inline void WeightSharedConvolutionalBoxPredictor::unsafe_arena_set_allocated_box_encodings_clip_range(
    ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.box_encodings_clip_range_);
  }
  _impl_.box_encodings_clip_range_ = box_encodings_clip_range;
  if (box_encodings_clip_range) {
    _impl_._has_bits_[0] |= 0x00000002u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.WeightSharedConvolutionalBoxPredictor.box_encodings_clip_range)
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* WeightSharedConvolutionalBoxPredictor::release_box_encodings_clip_range() {
  _impl_._has_bits_[0] &= ~0x00000002u;
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* temp = _impl_.box_encodings_clip_range_;
  _impl_.box_encodings_clip_range_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* WeightSharedConvolutionalBoxPredictor::unsafe_arena_release_box_encodings_clip_range() {
  // @@protoc_insertion_point(field_release:object_detection.protos.WeightSharedConvolutionalBoxPredictor.box_encodings_clip_range)
  _impl_._has_bits_[0] &= ~0x00000002u;
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* temp = _impl_.box_encodings_clip_range_;
  _impl_.box_encodings_clip_range_ = nullptr;
  return temp;
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* WeightSharedConvolutionalBoxPredictor::_internal_mutable_box_encodings_clip_range() {
  _impl_._has_bits_[0] |= 0x00000002u;
  if (_impl_.box_encodings_clip_range_ == nullptr) {
    auto* p = CreateMaybeMessage<::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange>(GetArenaForAllocation());
    _impl_.box_encodings_clip_range_ = p;
  }
  return _impl_.box_encodings_clip_range_;
}
inline ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* WeightSharedConvolutionalBoxPredictor::mutable_box_encodings_clip_range() {
  ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* _msg = _internal_mutable_box_encodings_clip_range();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.WeightSharedConvolutionalBoxPredictor.box_encodings_clip_range)
  return _msg;
}
inline void WeightSharedConvolutionalBoxPredictor::set_allocated_box_encodings_clip_range(::object_detection::protos::WeightSharedConvolutionalBoxPredictor_BoxEncodingsClipRange* box_encodings_clip_range) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete _impl_.box_encodings_clip_range_;
  }
  if (box_encodings_clip_range) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(box_encodings_clip_range);
    if (message_arena != submessage_arena) {
      box_encodings_clip_range = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, box_encodings_clip_range, submessage_arena);
    }
    _impl_._has_bits_[0] |= 0x00000002u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000002u;
  }
  _impl_.box_encodings_clip_range_ = box_encodings_clip_range;
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.WeightSharedConvolutionalBoxPredictor.box_encodings_clip_range)
}

// -------------------------------------------------------------------

// MaskRCNNBoxPredictor

// optional .object_detection.protos.Hyperparams fc_hyperparams = 1;
inline bool MaskRCNNBoxPredictor::_internal_has_fc_hyperparams() const {
  bool value = (_impl_._has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || _impl_.fc_hyperparams_ != nullptr);
  return value;
}
inline bool MaskRCNNBoxPredictor::has_fc_hyperparams() const {
  return _internal_has_fc_hyperparams();
}
inline const ::object_detection::protos::Hyperparams& MaskRCNNBoxPredictor::_internal_fc_hyperparams() const {
  const ::object_detection::protos::Hyperparams* p = _impl_.fc_hyperparams_;
  return p != nullptr ? *p : reinterpret_cast<const ::object_detection::protos::Hyperparams&>(
      ::object_detection::protos::_Hyperparams_default_instance_);
}
inline const ::object_detection::protos::Hyperparams& MaskRCNNBoxPredictor::fc_hyperparams() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.fc_hyperparams)
  return _internal_fc_hyperparams();
}
inline void MaskRCNNBoxPredictor::unsafe_arena_set_allocated_fc_hyperparams(
    ::object_detection::protos::Hyperparams* fc_hyperparams) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.fc_hyperparams_);
  }
  _impl_.fc_hyperparams_ = fc_hyperparams;
  if (fc_hyperparams) {
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.MaskRCNNBoxPredictor.fc_hyperparams)
}
inline ::object_detection::protos::Hyperparams* MaskRCNNBoxPredictor::release_fc_hyperparams() {
  _impl_._has_bits_[0] &= ~0x00000001u;
  ::object_detection::protos::Hyperparams* temp = _impl_.fc_hyperparams_;
  _impl_.fc_hyperparams_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::object_detection::protos::Hyperparams* MaskRCNNBoxPredictor::unsafe_arena_release_fc_hyperparams() {
  // @@protoc_insertion_point(field_release:object_detection.protos.MaskRCNNBoxPredictor.fc_hyperparams)
  _impl_._has_bits_[0] &= ~0x00000001u;
  ::object_detection::protos::Hyperparams* temp = _impl_.fc_hyperparams_;
  _impl_.fc_hyperparams_ = nullptr;
  return temp;
}
inline ::object_detection::protos::Hyperparams* MaskRCNNBoxPredictor::_internal_mutable_fc_hyperparams() {
  _impl_._has_bits_[0] |= 0x00000001u;
  if (_impl_.fc_hyperparams_ == nullptr) {
    auto* p = CreateMaybeMessage<::object_detection::protos::Hyperparams>(GetArenaForAllocation());
    _impl_.fc_hyperparams_ = p;
  }
  return _impl_.fc_hyperparams_;
}
inline ::object_detection::protos::Hyperparams* MaskRCNNBoxPredictor::mutable_fc_hyperparams() {
  ::object_detection::protos::Hyperparams* _msg = _internal_mutable_fc_hyperparams();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.MaskRCNNBoxPredictor.fc_hyperparams)
  return _msg;
}
inline void MaskRCNNBoxPredictor::set_allocated_fc_hyperparams(::object_detection::protos::Hyperparams* fc_hyperparams) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.fc_hyperparams_);
  }
  if (fc_hyperparams) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(fc_hyperparams));
    if (message_arena != submessage_arena) {
      fc_hyperparams = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, fc_hyperparams, submessage_arena);
    }
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  _impl_.fc_hyperparams_ = fc_hyperparams;
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.MaskRCNNBoxPredictor.fc_hyperparams)
}

// optional bool use_dropout = 2 [default = false];
inline bool MaskRCNNBoxPredictor::_internal_has_use_dropout() const {
  bool value = (_impl_._has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_use_dropout() const {
  return _internal_has_use_dropout();
}
inline void MaskRCNNBoxPredictor::clear_use_dropout() {
  _impl_.use_dropout_ = false;
  _impl_._has_bits_[0] &= ~0x00000004u;
}
inline bool MaskRCNNBoxPredictor::_internal_use_dropout() const {
  return _impl_.use_dropout_;
}
inline bool MaskRCNNBoxPredictor::use_dropout() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.use_dropout)
  return _internal_use_dropout();
}
inline void MaskRCNNBoxPredictor::_internal_set_use_dropout(bool value) {
  _impl_._has_bits_[0] |= 0x00000004u;
  _impl_.use_dropout_ = value;
}
inline void MaskRCNNBoxPredictor::set_use_dropout(bool value) {
  _internal_set_use_dropout(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.use_dropout)
}

// optional float dropout_keep_probability = 3 [default = 0.5];
inline bool MaskRCNNBoxPredictor::_internal_has_dropout_keep_probability() const {
  bool value = (_impl_._has_bits_[0] & 0x00000100u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_dropout_keep_probability() const {
  return _internal_has_dropout_keep_probability();
}
inline void MaskRCNNBoxPredictor::clear_dropout_keep_probability() {
  _impl_.dropout_keep_probability_ = 0.5f;
  _impl_._has_bits_[0] &= ~0x00000100u;
}
inline float MaskRCNNBoxPredictor::_internal_dropout_keep_probability() const {
  return _impl_.dropout_keep_probability_;
}
inline float MaskRCNNBoxPredictor::dropout_keep_probability() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.dropout_keep_probability)
  return _internal_dropout_keep_probability();
}
inline void MaskRCNNBoxPredictor::_internal_set_dropout_keep_probability(float value) {
  _impl_._has_bits_[0] |= 0x00000100u;
  _impl_.dropout_keep_probability_ = value;
}
inline void MaskRCNNBoxPredictor::set_dropout_keep_probability(float value) {
  _internal_set_dropout_keep_probability(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.dropout_keep_probability)
}

// optional int32 box_code_size = 4 [default = 4];
inline bool MaskRCNNBoxPredictor::_internal_has_box_code_size() const {
  bool value = (_impl_._has_bits_[0] & 0x00000200u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_box_code_size() const {
  return _internal_has_box_code_size();
}
inline void MaskRCNNBoxPredictor::clear_box_code_size() {
  _impl_.box_code_size_ = 4;
  _impl_._has_bits_[0] &= ~0x00000200u;
}
inline int32_t MaskRCNNBoxPredictor::_internal_box_code_size() const {
  return _impl_.box_code_size_;
}
inline int32_t MaskRCNNBoxPredictor::box_code_size() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.box_code_size)
  return _internal_box_code_size();
}
inline void MaskRCNNBoxPredictor::_internal_set_box_code_size(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000200u;
  _impl_.box_code_size_ = value;
}
inline void MaskRCNNBoxPredictor::set_box_code_size(int32_t value) {
  _internal_set_box_code_size(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.box_code_size)
}

// optional .object_detection.protos.Hyperparams conv_hyperparams = 5;
inline bool MaskRCNNBoxPredictor::_internal_has_conv_hyperparams() const {
  bool value = (_impl_._has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || _impl_.conv_hyperparams_ != nullptr);
  return value;
}
inline bool MaskRCNNBoxPredictor::has_conv_hyperparams() const {
  return _internal_has_conv_hyperparams();
}
inline const ::object_detection::protos::Hyperparams& MaskRCNNBoxPredictor::_internal_conv_hyperparams() const {
  const ::object_detection::protos::Hyperparams* p = _impl_.conv_hyperparams_;
  return p != nullptr ? *p : reinterpret_cast<const ::object_detection::protos::Hyperparams&>(
      ::object_detection::protos::_Hyperparams_default_instance_);
}
inline const ::object_detection::protos::Hyperparams& MaskRCNNBoxPredictor::conv_hyperparams() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.conv_hyperparams)
  return _internal_conv_hyperparams();
}
inline void MaskRCNNBoxPredictor::unsafe_arena_set_allocated_conv_hyperparams(
    ::object_detection::protos::Hyperparams* conv_hyperparams) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.conv_hyperparams_);
  }
  _impl_.conv_hyperparams_ = conv_hyperparams;
  if (conv_hyperparams) {
    _impl_._has_bits_[0] |= 0x00000002u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.MaskRCNNBoxPredictor.conv_hyperparams)
}
inline ::object_detection::protos::Hyperparams* MaskRCNNBoxPredictor::release_conv_hyperparams() {
  _impl_._has_bits_[0] &= ~0x00000002u;
  ::object_detection::protos::Hyperparams* temp = _impl_.conv_hyperparams_;
  _impl_.conv_hyperparams_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::object_detection::protos::Hyperparams* MaskRCNNBoxPredictor::unsafe_arena_release_conv_hyperparams() {
  // @@protoc_insertion_point(field_release:object_detection.protos.MaskRCNNBoxPredictor.conv_hyperparams)
  _impl_._has_bits_[0] &= ~0x00000002u;
  ::object_detection::protos::Hyperparams* temp = _impl_.conv_hyperparams_;
  _impl_.conv_hyperparams_ = nullptr;
  return temp;
}
inline ::object_detection::protos::Hyperparams* MaskRCNNBoxPredictor::_internal_mutable_conv_hyperparams() {
  _impl_._has_bits_[0] |= 0x00000002u;
  if (_impl_.conv_hyperparams_ == nullptr) {
    auto* p = CreateMaybeMessage<::object_detection::protos::Hyperparams>(GetArenaForAllocation());
    _impl_.conv_hyperparams_ = p;
  }
  return _impl_.conv_hyperparams_;
}
inline ::object_detection::protos::Hyperparams* MaskRCNNBoxPredictor::mutable_conv_hyperparams() {
  ::object_detection::protos::Hyperparams* _msg = _internal_mutable_conv_hyperparams();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.MaskRCNNBoxPredictor.conv_hyperparams)
  return _msg;
}
inline void MaskRCNNBoxPredictor::set_allocated_conv_hyperparams(::object_detection::protos::Hyperparams* conv_hyperparams) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.conv_hyperparams_);
  }
  if (conv_hyperparams) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(conv_hyperparams));
    if (message_arena != submessage_arena) {
      conv_hyperparams = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, conv_hyperparams, submessage_arena);
    }
    _impl_._has_bits_[0] |= 0x00000002u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000002u;
  }
  _impl_.conv_hyperparams_ = conv_hyperparams;
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.MaskRCNNBoxPredictor.conv_hyperparams)
}

// optional bool predict_instance_masks = 6 [default = false];
inline bool MaskRCNNBoxPredictor::_internal_has_predict_instance_masks() const {
  bool value = (_impl_._has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_predict_instance_masks() const {
  return _internal_has_predict_instance_masks();
}
inline void MaskRCNNBoxPredictor::clear_predict_instance_masks() {
  _impl_.predict_instance_masks_ = false;
  _impl_._has_bits_[0] &= ~0x00000008u;
}
inline bool MaskRCNNBoxPredictor::_internal_predict_instance_masks() const {
  return _impl_.predict_instance_masks_;
}
inline bool MaskRCNNBoxPredictor::predict_instance_masks() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.predict_instance_masks)
  return _internal_predict_instance_masks();
}
inline void MaskRCNNBoxPredictor::_internal_set_predict_instance_masks(bool value) {
  _impl_._has_bits_[0] |= 0x00000008u;
  _impl_.predict_instance_masks_ = value;
}
inline void MaskRCNNBoxPredictor::set_predict_instance_masks(bool value) {
  _internal_set_predict_instance_masks(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.predict_instance_masks)
}

// optional int32 mask_prediction_conv_depth = 7 [default = 256];
inline bool MaskRCNNBoxPredictor::_internal_has_mask_prediction_conv_depth() const {
  bool value = (_impl_._has_bits_[0] & 0x00000400u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_mask_prediction_conv_depth() const {
  return _internal_has_mask_prediction_conv_depth();
}
inline void MaskRCNNBoxPredictor::clear_mask_prediction_conv_depth() {
  _impl_.mask_prediction_conv_depth_ = 256;
  _impl_._has_bits_[0] &= ~0x00000400u;
}
inline int32_t MaskRCNNBoxPredictor::_internal_mask_prediction_conv_depth() const {
  return _impl_.mask_prediction_conv_depth_;
}
inline int32_t MaskRCNNBoxPredictor::mask_prediction_conv_depth() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.mask_prediction_conv_depth)
  return _internal_mask_prediction_conv_depth();
}
inline void MaskRCNNBoxPredictor::_internal_set_mask_prediction_conv_depth(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000400u;
  _impl_.mask_prediction_conv_depth_ = value;
}
inline void MaskRCNNBoxPredictor::set_mask_prediction_conv_depth(int32_t value) {
  _internal_set_mask_prediction_conv_depth(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.mask_prediction_conv_depth)
}

// optional bool predict_keypoints = 8 [default = false];
inline bool MaskRCNNBoxPredictor::_internal_has_predict_keypoints() const {
  bool value = (_impl_._has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_predict_keypoints() const {
  return _internal_has_predict_keypoints();
}
inline void MaskRCNNBoxPredictor::clear_predict_keypoints() {
  _impl_.predict_keypoints_ = false;
  _impl_._has_bits_[0] &= ~0x00000010u;
}
inline bool MaskRCNNBoxPredictor::_internal_predict_keypoints() const {
  return _impl_.predict_keypoints_;
}
inline bool MaskRCNNBoxPredictor::predict_keypoints() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.predict_keypoints)
  return _internal_predict_keypoints();
}
inline void MaskRCNNBoxPredictor::_internal_set_predict_keypoints(bool value) {
  _impl_._has_bits_[0] |= 0x00000010u;
  _impl_.predict_keypoints_ = value;
}
inline void MaskRCNNBoxPredictor::set_predict_keypoints(bool value) {
  _internal_set_predict_keypoints(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.predict_keypoints)
}

// optional int32 mask_height = 9 [default = 15];
inline bool MaskRCNNBoxPredictor::_internal_has_mask_height() const {
  bool value = (_impl_._has_bits_[0] & 0x00000800u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_mask_height() const {
  return _internal_has_mask_height();
}
inline void MaskRCNNBoxPredictor::clear_mask_height() {
  _impl_.mask_height_ = 15;
  _impl_._has_bits_[0] &= ~0x00000800u;
}
inline int32_t MaskRCNNBoxPredictor::_internal_mask_height() const {
  return _impl_.mask_height_;
}
inline int32_t MaskRCNNBoxPredictor::mask_height() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.mask_height)
  return _internal_mask_height();
}
inline void MaskRCNNBoxPredictor::_internal_set_mask_height(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000800u;
  _impl_.mask_height_ = value;
}
inline void MaskRCNNBoxPredictor::set_mask_height(int32_t value) {
  _internal_set_mask_height(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.mask_height)
}

// optional int32 mask_width = 10 [default = 15];
inline bool MaskRCNNBoxPredictor::_internal_has_mask_width() const {
  bool value = (_impl_._has_bits_[0] & 0x00001000u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_mask_width() const {
  return _internal_has_mask_width();
}
inline void MaskRCNNBoxPredictor::clear_mask_width() {
  _impl_.mask_width_ = 15;
  _impl_._has_bits_[0] &= ~0x00001000u;
}
inline int32_t MaskRCNNBoxPredictor::_internal_mask_width() const {
  return _impl_.mask_width_;
}
inline int32_t MaskRCNNBoxPredictor::mask_width() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.mask_width)
  return _internal_mask_width();
}
inline void MaskRCNNBoxPredictor::_internal_set_mask_width(int32_t value) {
  _impl_._has_bits_[0] |= 0x00001000u;
  _impl_.mask_width_ = value;
}
inline void MaskRCNNBoxPredictor::set_mask_width(int32_t value) {
  _internal_set_mask_width(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.mask_width)
}

// optional int32 mask_prediction_num_conv_layers = 11 [default = 2];
inline bool MaskRCNNBoxPredictor::_internal_has_mask_prediction_num_conv_layers() const {
  bool value = (_impl_._has_bits_[0] & 0x00002000u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_mask_prediction_num_conv_layers() const {
  return _internal_has_mask_prediction_num_conv_layers();
}
inline void MaskRCNNBoxPredictor::clear_mask_prediction_num_conv_layers() {
  _impl_.mask_prediction_num_conv_layers_ = 2;
  _impl_._has_bits_[0] &= ~0x00002000u;
}
inline int32_t MaskRCNNBoxPredictor::_internal_mask_prediction_num_conv_layers() const {
  return _impl_.mask_prediction_num_conv_layers_;
}
inline int32_t MaskRCNNBoxPredictor::mask_prediction_num_conv_layers() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.mask_prediction_num_conv_layers)
  return _internal_mask_prediction_num_conv_layers();
}
inline void MaskRCNNBoxPredictor::_internal_set_mask_prediction_num_conv_layers(int32_t value) {
  _impl_._has_bits_[0] |= 0x00002000u;
  _impl_.mask_prediction_num_conv_layers_ = value;
}
inline void MaskRCNNBoxPredictor::set_mask_prediction_num_conv_layers(int32_t value) {
  _internal_set_mask_prediction_num_conv_layers(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.mask_prediction_num_conv_layers)
}

// optional bool masks_are_class_agnostic = 12 [default = false];
inline bool MaskRCNNBoxPredictor::_internal_has_masks_are_class_agnostic() const {
  bool value = (_impl_._has_bits_[0] & 0x00000020u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_masks_are_class_agnostic() const {
  return _internal_has_masks_are_class_agnostic();
}
inline void MaskRCNNBoxPredictor::clear_masks_are_class_agnostic() {
  _impl_.masks_are_class_agnostic_ = false;
  _impl_._has_bits_[0] &= ~0x00000020u;
}
inline bool MaskRCNNBoxPredictor::_internal_masks_are_class_agnostic() const {
  return _impl_.masks_are_class_agnostic_;
}
inline bool MaskRCNNBoxPredictor::masks_are_class_agnostic() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.masks_are_class_agnostic)
  return _internal_masks_are_class_agnostic();
}
inline void MaskRCNNBoxPredictor::_internal_set_masks_are_class_agnostic(bool value) {
  _impl_._has_bits_[0] |= 0x00000020u;
  _impl_.masks_are_class_agnostic_ = value;
}
inline void MaskRCNNBoxPredictor::set_masks_are_class_agnostic(bool value) {
  _internal_set_masks_are_class_agnostic(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.masks_are_class_agnostic)
}

// optional bool share_box_across_classes = 13 [default = false];
inline bool MaskRCNNBoxPredictor::_internal_has_share_box_across_classes() const {
  bool value = (_impl_._has_bits_[0] & 0x00000040u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_share_box_across_classes() const {
  return _internal_has_share_box_across_classes();
}
inline void MaskRCNNBoxPredictor::clear_share_box_across_classes() {
  _impl_.share_box_across_classes_ = false;
  _impl_._has_bits_[0] &= ~0x00000040u;
}
inline bool MaskRCNNBoxPredictor::_internal_share_box_across_classes() const {
  return _impl_.share_box_across_classes_;
}
inline bool MaskRCNNBoxPredictor::share_box_across_classes() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.share_box_across_classes)
  return _internal_share_box_across_classes();
}
inline void MaskRCNNBoxPredictor::_internal_set_share_box_across_classes(bool value) {
  _impl_._has_bits_[0] |= 0x00000040u;
  _impl_.share_box_across_classes_ = value;
}
inline void MaskRCNNBoxPredictor::set_share_box_across_classes(bool value) {
  _internal_set_share_box_across_classes(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.share_box_across_classes)
}

// optional bool convolve_then_upsample_masks = 14 [default = false];
inline bool MaskRCNNBoxPredictor::_internal_has_convolve_then_upsample_masks() const {
  bool value = (_impl_._has_bits_[0] & 0x00000080u) != 0;
  return value;
}
inline bool MaskRCNNBoxPredictor::has_convolve_then_upsample_masks() const {
  return _internal_has_convolve_then_upsample_masks();
}
inline void MaskRCNNBoxPredictor::clear_convolve_then_upsample_masks() {
  _impl_.convolve_then_upsample_masks_ = false;
  _impl_._has_bits_[0] &= ~0x00000080u;
}
inline bool MaskRCNNBoxPredictor::_internal_convolve_then_upsample_masks() const {
  return _impl_.convolve_then_upsample_masks_;
}
inline bool MaskRCNNBoxPredictor::convolve_then_upsample_masks() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.MaskRCNNBoxPredictor.convolve_then_upsample_masks)
  return _internal_convolve_then_upsample_masks();
}
inline void MaskRCNNBoxPredictor::_internal_set_convolve_then_upsample_masks(bool value) {
  _impl_._has_bits_[0] |= 0x00000080u;
  _impl_.convolve_then_upsample_masks_ = value;
}
inline void MaskRCNNBoxPredictor::set_convolve_then_upsample_masks(bool value) {
  _internal_set_convolve_then_upsample_masks(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.MaskRCNNBoxPredictor.convolve_then_upsample_masks)
}

// -------------------------------------------------------------------

// RfcnBoxPredictor

// optional .object_detection.protos.Hyperparams conv_hyperparams = 1;
inline bool RfcnBoxPredictor::_internal_has_conv_hyperparams() const {
  bool value = (_impl_._has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || _impl_.conv_hyperparams_ != nullptr);
  return value;
}
inline bool RfcnBoxPredictor::has_conv_hyperparams() const {
  return _internal_has_conv_hyperparams();
}
inline const ::object_detection::protos::Hyperparams& RfcnBoxPredictor::_internal_conv_hyperparams() const {
  const ::object_detection::protos::Hyperparams* p = _impl_.conv_hyperparams_;
  return p != nullptr ? *p : reinterpret_cast<const ::object_detection::protos::Hyperparams&>(
      ::object_detection::protos::_Hyperparams_default_instance_);
}
inline const ::object_detection::protos::Hyperparams& RfcnBoxPredictor::conv_hyperparams() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.RfcnBoxPredictor.conv_hyperparams)
  return _internal_conv_hyperparams();
}
inline void RfcnBoxPredictor::unsafe_arena_set_allocated_conv_hyperparams(
    ::object_detection::protos::Hyperparams* conv_hyperparams) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.conv_hyperparams_);
  }
  _impl_.conv_hyperparams_ = conv_hyperparams;
  if (conv_hyperparams) {
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:object_detection.protos.RfcnBoxPredictor.conv_hyperparams)
}
inline ::object_detection::protos::Hyperparams* RfcnBoxPredictor::release_conv_hyperparams() {
  _impl_._has_bits_[0] &= ~0x00000001u;
  ::object_detection::protos::Hyperparams* temp = _impl_.conv_hyperparams_;
  _impl_.conv_hyperparams_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::object_detection::protos::Hyperparams* RfcnBoxPredictor::unsafe_arena_release_conv_hyperparams() {
  // @@protoc_insertion_point(field_release:object_detection.protos.RfcnBoxPredictor.conv_hyperparams)
  _impl_._has_bits_[0] &= ~0x00000001u;
  ::object_detection::protos::Hyperparams* temp = _impl_.conv_hyperparams_;
  _impl_.conv_hyperparams_ = nullptr;
  return temp;
}
inline ::object_detection::protos::Hyperparams* RfcnBoxPredictor::_internal_mutable_conv_hyperparams() {
  _impl_._has_bits_[0] |= 0x00000001u;
  if (_impl_.conv_hyperparams_ == nullptr) {
    auto* p = CreateMaybeMessage<::object_detection::protos::Hyperparams>(GetArenaForAllocation());
    _impl_.conv_hyperparams_ = p;
  }
  return _impl_.conv_hyperparams_;
}
inline ::object_detection::protos::Hyperparams* RfcnBoxPredictor::mutable_conv_hyperparams() {
  ::object_detection::protos::Hyperparams* _msg = _internal_mutable_conv_hyperparams();
  // @@protoc_insertion_point(field_mutable:object_detection.protos.RfcnBoxPredictor.conv_hyperparams)
  return _msg;
}
inline void RfcnBoxPredictor::set_allocated_conv_hyperparams(::object_detection::protos::Hyperparams* conv_hyperparams) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(_impl_.conv_hyperparams_);
  }
  if (conv_hyperparams) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalGetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(conv_hyperparams));
    if (message_arena != submessage_arena) {
      conv_hyperparams = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, conv_hyperparams, submessage_arena);
    }
    _impl_._has_bits_[0] |= 0x00000001u;
  } else {
    _impl_._has_bits_[0] &= ~0x00000001u;
  }
  _impl_.conv_hyperparams_ = conv_hyperparams;
  // @@protoc_insertion_point(field_set_allocated:object_detection.protos.RfcnBoxPredictor.conv_hyperparams)
}

// optional int32 num_spatial_bins_height = 2 [default = 3];
inline bool RfcnBoxPredictor::_internal_has_num_spatial_bins_height() const {
  bool value = (_impl_._has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool RfcnBoxPredictor::has_num_spatial_bins_height() const {
  return _internal_has_num_spatial_bins_height();
}
inline void RfcnBoxPredictor::clear_num_spatial_bins_height() {
  _impl_.num_spatial_bins_height_ = 3;
  _impl_._has_bits_[0] &= ~0x00000002u;
}
inline int32_t RfcnBoxPredictor::_internal_num_spatial_bins_height() const {
  return _impl_.num_spatial_bins_height_;
}
inline int32_t RfcnBoxPredictor::num_spatial_bins_height() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.RfcnBoxPredictor.num_spatial_bins_height)
  return _internal_num_spatial_bins_height();
}
inline void RfcnBoxPredictor::_internal_set_num_spatial_bins_height(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000002u;
  _impl_.num_spatial_bins_height_ = value;
}
inline void RfcnBoxPredictor::set_num_spatial_bins_height(int32_t value) {
  _internal_set_num_spatial_bins_height(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.RfcnBoxPredictor.num_spatial_bins_height)
}

// optional int32 num_spatial_bins_width = 3 [default = 3];
inline bool RfcnBoxPredictor::_internal_has_num_spatial_bins_width() const {
  bool value = (_impl_._has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool RfcnBoxPredictor::has_num_spatial_bins_width() const {
  return _internal_has_num_spatial_bins_width();
}
inline void RfcnBoxPredictor::clear_num_spatial_bins_width() {
  _impl_.num_spatial_bins_width_ = 3;
  _impl_._has_bits_[0] &= ~0x00000004u;
}
inline int32_t RfcnBoxPredictor::_internal_num_spatial_bins_width() const {
  return _impl_.num_spatial_bins_width_;
}
inline int32_t RfcnBoxPredictor::num_spatial_bins_width() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.RfcnBoxPredictor.num_spatial_bins_width)
  return _internal_num_spatial_bins_width();
}
inline void RfcnBoxPredictor::_internal_set_num_spatial_bins_width(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000004u;
  _impl_.num_spatial_bins_width_ = value;
}
inline void RfcnBoxPredictor::set_num_spatial_bins_width(int32_t value) {
  _internal_set_num_spatial_bins_width(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.RfcnBoxPredictor.num_spatial_bins_width)
}

// optional int32 depth = 4 [default = 1024];
inline bool RfcnBoxPredictor::_internal_has_depth() const {
  bool value = (_impl_._has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool RfcnBoxPredictor::has_depth() const {
  return _internal_has_depth();
}
inline void RfcnBoxPredictor::clear_depth() {
  _impl_.depth_ = 1024;
  _impl_._has_bits_[0] &= ~0x00000008u;
}
inline int32_t RfcnBoxPredictor::_internal_depth() const {
  return _impl_.depth_;
}
inline int32_t RfcnBoxPredictor::depth() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.RfcnBoxPredictor.depth)
  return _internal_depth();
}
inline void RfcnBoxPredictor::_internal_set_depth(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000008u;
  _impl_.depth_ = value;
}
inline void RfcnBoxPredictor::set_depth(int32_t value) {
  _internal_set_depth(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.RfcnBoxPredictor.depth)
}

// optional int32 box_code_size = 5 [default = 4];
inline bool RfcnBoxPredictor::_internal_has_box_code_size() const {
  bool value = (_impl_._has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool RfcnBoxPredictor::has_box_code_size() const {
  return _internal_has_box_code_size();
}
inline void RfcnBoxPredictor::clear_box_code_size() {
  _impl_.box_code_size_ = 4;
  _impl_._has_bits_[0] &= ~0x00000010u;
}
inline int32_t RfcnBoxPredictor::_internal_box_code_size() const {
  return _impl_.box_code_size_;
}
inline int32_t RfcnBoxPredictor::box_code_size() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.RfcnBoxPredictor.box_code_size)
  return _internal_box_code_size();
}
inline void RfcnBoxPredictor::_internal_set_box_code_size(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000010u;
  _impl_.box_code_size_ = value;
}
inline void RfcnBoxPredictor::set_box_code_size(int32_t value) {
  _internal_set_box_code_size(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.RfcnBoxPredictor.box_code_size)
}

// optional int32 crop_height = 6 [default = 12];
inline bool RfcnBoxPredictor::_internal_has_crop_height() const {
  bool value = (_impl_._has_bits_[0] & 0x00000020u) != 0;
  return value;
}
inline bool RfcnBoxPredictor::has_crop_height() const {
  return _internal_has_crop_height();
}
inline void RfcnBoxPredictor::clear_crop_height() {
  _impl_.crop_height_ = 12;
  _impl_._has_bits_[0] &= ~0x00000020u;
}
inline int32_t RfcnBoxPredictor::_internal_crop_height() const {
  return _impl_.crop_height_;
}
inline int32_t RfcnBoxPredictor::crop_height() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.RfcnBoxPredictor.crop_height)
  return _internal_crop_height();
}
inline void RfcnBoxPredictor::_internal_set_crop_height(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000020u;
  _impl_.crop_height_ = value;
}
inline void RfcnBoxPredictor::set_crop_height(int32_t value) {
  _internal_set_crop_height(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.RfcnBoxPredictor.crop_height)
}

// optional int32 crop_width = 7 [default = 12];
inline bool RfcnBoxPredictor::_internal_has_crop_width() const {
  bool value = (_impl_._has_bits_[0] & 0x00000040u) != 0;
  return value;
}
inline bool RfcnBoxPredictor::has_crop_width() const {
  return _internal_has_crop_width();
}
inline void RfcnBoxPredictor::clear_crop_width() {
  _impl_.crop_width_ = 12;
  _impl_._has_bits_[0] &= ~0x00000040u;
}
inline int32_t RfcnBoxPredictor::_internal_crop_width() const {
  return _impl_.crop_width_;
}
inline int32_t RfcnBoxPredictor::crop_width() const {
  // @@protoc_insertion_point(field_get:object_detection.protos.RfcnBoxPredictor.crop_width)
  return _internal_crop_width();
}
inline void RfcnBoxPredictor::_internal_set_crop_width(int32_t value) {
  _impl_._has_bits_[0] |= 0x00000040u;
  _impl_.crop_width_ = value;
}
inline void RfcnBoxPredictor::set_crop_width(int32_t value) {
  _internal_set_crop_width(value);
  // @@protoc_insertion_point(field_set:object_detection.protos.RfcnBoxPredictor.crop_width)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------


// @@protoc_insertion_point(namespace_scope)

}  // namespace protos
}  // namespace object_detection

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter>() {
  return ::object_detection::protos::WeightSharedConvolutionalBoxPredictor_ScoreConverter_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_object_5fdetection_2fprotos_2fbox_5fpredictor_2eproto
